summaryrefslogtreecommitdiffstats
path: root/quanta
diff options
context:
space:
mode:
Diffstat (limited to 'quanta')
-rw-r--r--quanta/components/csseditor/csseditor.h4
-rw-r--r--quanta/components/debugger/dbgp/dbgpnetwork.cpp10
-rw-r--r--quanta/components/debugger/dbgp/dbgpnetwork.h2
-rw-r--r--quanta/components/debugger/gubed/quantadebuggergubed.cpp10
-rw-r--r--quanta/components/debugger/gubed/quantadebuggergubed.h2
-rw-r--r--quanta/dialogs/copyto.cpp22
-rw-r--r--quanta/dialogs/copyto.h2
-rw-r--r--quanta/dialogs/dirtydlg.cpp14
-rw-r--r--quanta/dialogs/dirtydlg.h2
-rw-r--r--quanta/dialogs/dtepeditdlg.cpp14
-rw-r--r--quanta/dialogs/dtepeditdlg.h14
-rw-r--r--quanta/dialogs/settings/parseroptions.cpp2
-rw-r--r--quanta/dialogs/settings/parseroptions.h6
-rw-r--r--quanta/dialogs/settings/previewoptions.h2
-rw-r--r--quanta/dialogs/tagdialogs/tagdialog.cpp2
-rw-r--r--quanta/dialogs/tagdialogs/tagimgdlg.cpp6
-rw-r--r--quanta/parsers/dtd/dtd.cpp4
-rw-r--r--quanta/parsers/dtd/dtdparser.cpp4
-rw-r--r--quanta/parts/kafka/htmlenhancer.cpp2
-rw-r--r--quanta/parts/kafka/htmlenhancer.h4
-rw-r--r--quanta/parts/kafka/kafkasyncoptions.cpp2
-rw-r--r--quanta/parts/kafka/kafkasyncoptions.h6
-rw-r--r--quanta/parts/kafka/nodeenhancer.h4
-rw-r--r--quanta/parts/kafka/undoredo.cpp2
-rw-r--r--quanta/parts/kafka/wkafkapart.cpp2
-rw-r--r--quanta/parts/kafka/wkafkapart.h4
-rw-r--r--quanta/parts/preview/whtmlpart.cpp2
-rw-r--r--quanta/plugins/quantaplugininterface.cpp4
-rw-r--r--quanta/project/project.cpp14
-rw-r--r--quanta/project/project.h4
-rw-r--r--quanta/project/projectnewlocal.cpp2
-rw-r--r--quanta/project/projectprivate.cpp24
-rw-r--r--quanta/project/projectprivate.h4
-rw-r--r--quanta/project/projectupload.cpp26
-rw-r--r--quanta/project/projectupload.h6
-rw-r--r--quanta/project/rescanprj.cpp30
-rw-r--r--quanta/project/rescanprj.h4
-rw-r--r--quanta/quanta_uml.xmi30
-rw-r--r--quanta/src/document.cpp6
-rw-r--r--quanta/src/document.h6
-rw-r--r--quanta/src/dtds.cpp10
-rw-r--r--quanta/src/dtds.h2
-rw-r--r--quanta/src/kqapp.cpp4
-rw-r--r--quanta/src/quanta.cpp12
-rw-r--r--quanta/src/quanta.h4
-rw-r--r--quanta/src/quanta_init.cpp16
-rw-r--r--quanta/src/quanta_init.h4
-rw-r--r--quanta/src/quantadoc.h2
-rw-r--r--quanta/treeviews/basetreeview.cpp24
-rw-r--r--quanta/treeviews/basetreeview.h18
-rw-r--r--quanta/treeviews/docfolder.cpp4
-rw-r--r--quanta/treeviews/docfolder.h6
-rw-r--r--quanta/treeviews/docitem.h2
-rw-r--r--quanta/treeviews/doctreeview.cpp2
-rw-r--r--quanta/treeviews/filestreeview.cpp2
-rw-r--r--quanta/treeviews/filestreeview.h4
-rw-r--r--quanta/treeviews/servertreeview.cpp2
-rw-r--r--quanta/treeviews/servertreeview.h4
-rw-r--r--quanta/treeviews/structtreeview.h4
-rw-r--r--quanta/treeviews/templatestreeview.cpp36
-rw-r--r--quanta/utility/quantabookmarks.cpp2
-rw-r--r--quanta/utility/quantacommon.cpp4
-rw-r--r--quanta/utility/quantacommon.h10
-rw-r--r--quanta/utility/quantanetaccess.cpp16
-rw-r--r--quanta/utility/quantanetaccess.h2
-rw-r--r--quanta/utility/tagactionset.cpp2
66 files changed, 254 insertions, 254 deletions
diff --git a/quanta/components/csseditor/csseditor.h b/quanta/components/csseditor/csseditor.h
index aee0695b..fa9e3339 100644
--- a/quanta/components/csseditor/csseditor.h
+++ b/quanta/components/csseditor/csseditor.h
@@ -26,7 +26,7 @@
#include <tqsignal.h>
class propertySetter;
-class KConfig;
+class TDEConfig;
class KHTMLPart;
class TQListViewItem;
class TQDomNodeList;
@@ -75,7 +75,7 @@ class CSSEditor : public CSSEditorS
m_fileToPreview;
bool m_isFileToPreviewExternal;
- KConfig *m_config;
+ TDEConfig *m_config;
//sourceFileName;
diff --git a/quanta/components/debugger/dbgp/dbgpnetwork.h b/quanta/components/debugger/dbgp/dbgpnetwork.h
index 8cce9d6a..1ac8e2f4 100644
--- a/quanta/components/debugger/dbgp/dbgpnetwork.h
+++ b/quanta/components/debugger/dbgp/dbgpnetwork.h
@@ -35,7 +35,7 @@ class DBGpNetwork : public TQObject
private:
KNetwork::KStreamSocket *m_socket;
- KNetwork::KServerSocket *m_server;
+ KNetwork::TDEServerSocket *m_server;
TQByteArrayFifo m_fifo;
bool m_useproxy;
long m_datalen;
diff --git a/quanta/components/debugger/gubed/quantadebuggergubed.h b/quanta/components/debugger/gubed/quantadebuggergubed.h
index 5b53f128..ead8ffd5 100644
--- a/quanta/components/debugger/gubed/quantadebuggergubed.h
+++ b/quanta/components/debugger/gubed/quantadebuggergubed.h
@@ -98,7 +98,7 @@ class QuantaDebuggerGubed : public DebuggerClient
private:
KNetwork::KStreamSocket *m_socket;
- KNetwork::KServerSocket *m_server;
+ KNetwork::TDEServerSocket *m_server;
TQString m_command, m_buffer;
long m_datalen;
diff --git a/quanta/dialogs/copyto.cpp b/quanta/dialogs/copyto.cpp
index 9f66cb11..bc2543dc 100644
--- a/quanta/dialogs/copyto.cpp
+++ b/quanta/dialogs/copyto.cpp
@@ -54,17 +54,17 @@ KURL CopyTo::copy(const KURL& urlToCopy, const KURL& destination)
KURL destURL;
if (doCopy)
{
- KIO::UDSEntry entry;
- KIO::NetAccess::stat(urlToCopy, entry, 0);
+ TDEIO::UDSEntry entry;
+ TDEIO::NetAccess::stat(urlToCopy, entry, 0);
KFileItem item(entry, urlToCopy, false, true);
destURL = targetDirURL;
destURL.setPath(destURL.path(1) + urlToCopy.fileName(false));
if (item.isDir())
destURL.adjustPath(1);
- KIO::CopyJob *job = KIO::copy(urlToCopy, destURL, true);
- connect( job, TQT_SIGNAL(result( KIO::Job *)),
- TQT_SLOT (slotResult( KIO::Job *)));
+ TDEIO::CopyJob *job = TDEIO::copy(urlToCopy, destURL, true);
+ connect( job, TQT_SIGNAL(result( TDEIO::Job *)),
+ TQT_SLOT (slotResult( TDEIO::Job *)));
TQString path = destURL.path();
if (path != "." && path != "..")
@@ -74,7 +74,7 @@ KURL CopyTo::copy(const KURL& urlToCopy, const KURL& destination)
return destURL;
}
-void CopyTo::slotResult( KIO::Job *)
+void CopyTo::slotResult( TDEIO::Job *)
{
emit addFilesToProject(m_destList);
emit deleteDialog(this);
@@ -98,14 +98,14 @@ KURL::List CopyTo::copy(const KURL::List& sourceList, const KURL& destination )
doCopy = QExtFileInfo::createDir(targetDirURL, 0L);
}
- KIO::UDSEntry entry;
+ TDEIO::UDSEntry entry;
if (doCopy)
{
TQString path;
for (uint i = 0; i < sourceList.count(); i++)
{
KURL srcURL = sourceList[i];
- KIO::NetAccess::stat(srcURL, entry, 0);
+ TDEIO::NetAccess::stat(srcURL, entry, 0);
KFileItem item(entry, srcURL, false, true);
KURL u = targetDirURL;
u.setPath(targetDirURL.path(1) + srcURL.fileName());
@@ -116,9 +116,9 @@ KURL::List CopyTo::copy(const KURL::List& sourceList, const KURL& destination )
m_destList.append(u);
}
- KIO::CopyJob *job = KIO::copy(sourceList, targetDirURL, true);
- connect( job, TQT_SIGNAL(result( KIO::Job *)),
- TQT_SLOT (slotResult( KIO::Job *)));
+ TDEIO::CopyJob *job = TDEIO::copy(sourceList, targetDirURL, true);
+ connect( job, TQT_SIGNAL(result( TDEIO::Job *)),
+ TQT_SLOT (slotResult( TDEIO::Job *)));
}
return m_destList;
diff --git a/quanta/dialogs/copyto.h b/quanta/dialogs/copyto.h
index 16b7410b..29412488 100644
--- a/quanta/dialogs/copyto.h
+++ b/quanta/dialogs/copyto.h
@@ -39,7 +39,7 @@ public:
KURL::List copy(const KURL::List& sourceList, const KURL &destination );
public slots: // Public slots
- void slotResult( KIO::Job *);
+ void slotResult( TDEIO::Job *);
signals:
void addFilesToProject(const KURL::List&);
diff --git a/quanta/dialogs/dirtydlg.h b/quanta/dialogs/dirtydlg.h
index 04cf3824..4b6d9232 100644
--- a/quanta/dialogs/dirtydlg.h
+++ b/quanta/dialogs/dirtydlg.h
@@ -40,7 +40,7 @@ protected slots: // Protected slots
/** No descriptions */
void slotCompareDone(TDEProcess*);
/** No descriptions */
- void slotResult(KIO::Job *);
+ void slotResult(TDEIO::Job *);
/** No descriptions */
virtual void closeEvent(TQCloseEvent* ev);
diff --git a/quanta/dialogs/dtepeditdlg.cpp b/quanta/dialogs/dtepeditdlg.cpp
index c2595716..bbb3456d 100644
--- a/quanta/dialogs/dtepeditdlg.cpp
+++ b/quanta/dialogs/dtepeditdlg.cpp
@@ -46,7 +46,7 @@ DTEPEditDlg::DTEPEditDlg(const TQString& descriptionFile, TQWidget *parent, cons
nameEdit->setFocus();
m_descriptionFile = descriptionFile;
- m_config = new KConfig(m_descriptionFile, false, false);
+ m_config = new TDEConfig(m_descriptionFile, false, false);
init();
}
@@ -215,7 +215,7 @@ void DTEPEditDlg::saveResult()
TQFile f(targetFile);
if (f.exists())
f.remove();
- KConfig* newConfig = m_config->copyTo(targetFile);
+ TDEConfig* newConfig = m_config->copyTo(targetFile);
newConfig->sync();
writeGeneral(newConfig);
writePages(newConfig);
@@ -226,7 +226,7 @@ void DTEPEditDlg::saveResult()
}
}
-void DTEPEditDlg::writeGeneral(KConfig *config)
+void DTEPEditDlg::writeGeneral(TDEConfig *config)
{
config->setGroup("General");
writeEntry(config, "Name", nameEdit->text());
@@ -246,7 +246,7 @@ void DTEPEditDlg::writeGeneral(KConfig *config)
writeEntry(config, "Names", toolbarsEdit->text());
}
-void DTEPEditDlg::writePages(KConfig *config)
+void DTEPEditDlg::writePages(TDEConfig *config)
{
config->deleteGroup("Pages");
if (m_family == 0)
@@ -292,7 +292,7 @@ void DTEPEditDlg::writePages(KConfig *config)
}
}
-void DTEPEditDlg::writeParserRules(KConfig *config)
+void DTEPEditDlg::writeParserRules(TDEConfig *config)
{
config->setGroup("Extra rules");
config->writeEntry("MinusAllowedInWord", enableMinusInWords->isChecked());
@@ -378,7 +378,7 @@ void DTEPEditDlg::readStructures()
}
}
-void DTEPEditDlg::writeStructures(KConfig *config)
+void DTEPEditDlg::writeStructures(TDEConfig *config)
{
config->setGroup("Extra rules");
config->writeEntry("StructGroupsCount", m_structGroups.count());
@@ -544,7 +544,7 @@ void DTEPEditDlg::slotDeleteStructGroup()
}
}
-void DTEPEditDlg::writeEntry(KConfig *config, const TQString &key, const TQString &value)
+void DTEPEditDlg::writeEntry(TDEConfig *config, const TQString &key, const TQString &value)
{
if (value.isEmpty())
config->deleteEntry(key);
diff --git a/quanta/dialogs/dtepeditdlg.h b/quanta/dialogs/dtepeditdlg.h
index 3e0f942f..a570881d 100644
--- a/quanta/dialogs/dtepeditdlg.h
+++ b/quanta/dialogs/dtepeditdlg.h
@@ -26,7 +26,7 @@
@author Andras Mantia
*/
-class KConfig;
+class TDEConfig;
class DTEPStructureEditDlgS;
struct StructGroup {
@@ -74,14 +74,14 @@ class DTEPEditDlg : public DTEPEditDlgS
void readStructures();
StructGroup readFromStructDlg(DTEPStructureEditDlgS *structDlg);
- void writeGeneral(KConfig *config);
- void writePages(KConfig *config);
- void writeParserRules(KConfig *config);
- void writeStructures(KConfig *config);
- void writeEntry(KConfig *config, const TQString &key, const TQString &value);
+ void writeGeneral(TDEConfig *config);
+ void writePages(TDEConfig *config);
+ void writeParserRules(TDEConfig *config);
+ void writeStructures(TDEConfig *config);
+ void writeEntry(TDEConfig *config, const TQString &key, const TQString &value);
TQString m_descriptionFile;
- KConfig *m_config;
+ TDEConfig *m_config;
int m_family;
TQWidget *m_pagesWidget;
TQValueList<StructGroup> m_structGroups;
diff --git a/quanta/dialogs/settings/parseroptions.cpp b/quanta/dialogs/settings/parseroptions.cpp
index f3fad631..92ff1206 100644
--- a/quanta/dialogs/settings/parseroptions.cpp
+++ b/quanta/dialogs/settings/parseroptions.cpp
@@ -25,7 +25,7 @@
* Constructs a ParserOptions which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/
-ParserOptions::ParserOptions( KConfig *a_config, TQWidget* parent, const char* name )
+ParserOptions::ParserOptions( TDEConfig *a_config, TQWidget* parent, const char* name )
: ParserOptionsUI( parent, name )
{
config = a_config;
diff --git a/quanta/dialogs/settings/parseroptions.h b/quanta/dialogs/settings/parseroptions.h
index 39d7bd53..89058786 100644
--- a/quanta/dialogs/settings/parseroptions.h
+++ b/quanta/dialogs/settings/parseroptions.h
@@ -18,7 +18,7 @@
#include "parseroptionsui.h"
-class KConfig;
+class TDEConfig;
class ParserOptions : public ParserOptionsUI
{
@@ -26,13 +26,13 @@ class ParserOptions : public ParserOptionsUI
public:
- ParserOptions( KConfig *config, TQWidget* parent = 0, const char* name = 0);
+ ParserOptions( TDEConfig *config, TQWidget* parent = 0, const char* name = 0);
~ParserOptions();
void updateConfig();
protected:
- KConfig *config;
+ TDEConfig *config;
};
#endif // PARSEROPTIONS_H
diff --git a/quanta/dialogs/settings/previewoptions.h b/quanta/dialogs/settings/previewoptions.h
index 898345af..f688d02d 100644
--- a/quanta/dialogs/settings/previewoptions.h
+++ b/quanta/dialogs/settings/previewoptions.h
@@ -20,7 +20,7 @@
#include "previewoptionss.h"
-class KConfig;
+class TDEConfig;
class PreviewOptions : public PreviewOptionsS {
Q_OBJECT
diff --git a/quanta/dialogs/tagdialogs/tagdialog.cpp b/quanta/dialogs/tagdialogs/tagdialog.cpp
index bb379ce7..4b491b26 100644
--- a/quanta/dialogs/tagdialogs/tagdialog.cpp
+++ b/quanta/dialogs/tagdialogs/tagdialog.cpp
@@ -192,7 +192,7 @@ void TagDialog::parseTag()
addTab( mainDlg, i18n("Main") );
}
- KConfig *dtdConfig = new KConfig(dtdTag->parentDTD->fileName);
+ TDEConfig *dtdConfig = new TDEConfig(dtdTag->parentDTD->fileName);
dtdConfig->setGroup("General");
int numOfPages = dtdConfig->readNumEntry("NumOfPages");
extraPageList = new TQPtrList<Tagxml>();
diff --git a/quanta/dialogs/tagdialogs/tagimgdlg.cpp b/quanta/dialogs/tagdialogs/tagimgdlg.cpp
index 17285d96..d2a680f5 100644
--- a/quanta/dialogs/tagdialogs/tagimgdlg.cpp
+++ b/quanta/dialogs/tagdialogs/tagimgdlg.cpp
@@ -54,7 +54,7 @@ TagImgDlg::~TagImgDlg()
{
if (isTmpFile)
{
- KIO::NetAccess::removeTempFile(imgFileName);
+ TDEIO::NetAccess::removeTempFile(imgFileName);
isTmpFile = false;
}
}
@@ -64,7 +64,7 @@ void TagImgDlg::slotImageSet(const KURL& imageURL)
{
if (isTmpFile)
{
- KIO::NetAccess::removeTempFile(imgFileName);
+ TDEIO::NetAccess::removeTempFile(imgFileName);
isTmpFile = false;
}
if (imageURL.isLocalFile())
@@ -72,7 +72,7 @@ void TagImgDlg::slotImageSet(const KURL& imageURL)
imgFileName = imageURL.path();
} else
{
- KIO::NetAccess::download(imageURL, imgFileName, this);
+ TDEIO::NetAccess::download(imageURL, imgFileName, this);
isTmpFile = true;
}
widgetImg->slotSetImage(imgFileName);
diff --git a/quanta/parsers/dtd/dtd.cpp b/quanta/parsers/dtd/dtd.cpp
index 92e1e8f8..34826ca4 100644
--- a/quanta/parsers/dtd/dtd.cpp
+++ b/quanta/parsers/dtd/dtd.cpp
@@ -112,7 +112,7 @@ void DTD::writeTagFiles()
}
}
- KConfig config(dirName + "description.rc");
+ TDEConfig config(dirName + "description.rc");
config.setGroup("General");
config.writeEntry("Name", TQFileInfo(m_dtdURL.fileName()).baseName()); //TODO: get from the DTD!
config.writeEntry("NickName", TQFileInfo(m_dtdURL.fileName()).baseName()); //TODO: get from the user!
@@ -122,7 +122,7 @@ void DTD::writeTagFiles()
bool DTD::parseDTD(const KURL &url)
{
TQString fileName = TQString();
- if (!KIO::NetAccess::download(url, fileName))
+ if (!TDEIO::NetAccess::download(url, fileName))
{
KMessageBox::error(0, i18n("<qt>Cannot download the DTD from <b>%1</b>.</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)));
return false;
diff --git a/quanta/parsers/dtd/dtdparser.cpp b/quanta/parsers/dtd/dtdparser.cpp
index c8eb2a98..07d571f8 100644
--- a/quanta/parsers/dtd/dtdparser.cpp
+++ b/quanta/parsers/dtd/dtdparser.cpp
@@ -73,7 +73,7 @@ bool DTDParser::parse(const TQString &targetDir, bool entitiesOnly)
{
bool fineTune = false;
TQString fileName = TQString();
- if (!KIO::NetAccess::download(m_dtdURL, fileName, 0))
+ if (!TDEIO::NetAccess::download(m_dtdURL, fileName, 0))
{
KMessageBox::error(0, i18n("<qt>Cannot download the DTD from <b>%1</b>.</qt>").arg( m_dtdURL.prettyURL(0, KURL::StripFileProtocol)));
return false;
@@ -190,7 +190,7 @@ bool DTDParser::parse(const TQString &targetDir, bool entitiesOnly)
void DTDParser::writeDescriptionRC()
{
- KConfig config(DTD::dirName + "description.rc");
+ TDEConfig config(DTD::dirName + "description.rc");
config.setGroup("General");
config.writeEntry("Name", m_name);
config.writeEntry("NickName", m_nickName);
diff --git a/quanta/parts/kafka/htmlenhancer.cpp b/quanta/parts/kafka/htmlenhancer.cpp
index b2647423..8077a76b 100644
--- a/quanta/parts/kafka/htmlenhancer.cpp
+++ b/quanta/parts/kafka/htmlenhancer.cpp
@@ -385,7 +385,7 @@ void HTMLEnhancer::postUnenhanceNode(DOM::Node domNode)
}
}
-void HTMLEnhancer::readConfig(KConfig *m_config)
+void HTMLEnhancer::readConfig(TDEConfig *m_config)
{
m_config->setGroup("HTML Enhancer");
m_showIconForScripts = m_config->readBoolEntry("Show Scripts Icons", true);
diff --git a/quanta/parts/kafka/htmlenhancer.h b/quanta/parts/kafka/htmlenhancer.h
index ac3753c0..9fdc8658 100644
--- a/quanta/parts/kafka/htmlenhancer.h
+++ b/quanta/parts/kafka/htmlenhancer.h
@@ -22,7 +22,7 @@
#include "nodeenhancer.h"
-class KConfig;
+class TDEConfig;
class Node;
class KafkaDocument;
class KStandardDirs;
@@ -70,7 +70,7 @@ public:
* Read the config.
* @m_config The config to read.
*/
- void readConfig(KConfig *m_config);
+ void readConfig(TDEConfig *m_config);
/**
* Set the base URL of the current document to update src attrs.
diff --git a/quanta/parts/kafka/kafkasyncoptions.cpp b/quanta/parts/kafka/kafkasyncoptions.cpp
index 26013c25..2c37f0cd 100644
--- a/quanta/parts/kafka/kafkasyncoptions.cpp
+++ b/quanta/parts/kafka/kafkasyncoptions.cpp
@@ -25,7 +25,7 @@
#include "kafkasyncoptions.h"
#include "kafkasyncoptions.moc"
-KafkaSyncOptions::KafkaSyncOptions( KConfig *a_config, TQWidget* parent, const char* name )
+KafkaSyncOptions::KafkaSyncOptions( TDEConfig *a_config, TQWidget* parent, const char* name )
: KafkaSyncOptionsUI( parent, name )
{
config = a_config;
diff --git a/quanta/parts/kafka/kafkasyncoptions.h b/quanta/parts/kafka/kafkasyncoptions.h
index 9009f6b7..c924b34e 100644
--- a/quanta/parts/kafka/kafkasyncoptions.h
+++ b/quanta/parts/kafka/kafkasyncoptions.h
@@ -20,7 +20,7 @@
#include "kafkasyncoptionsui.h"
-class KConfig;
+class TDEConfig;
class KafkaSyncOptions : public KafkaSyncOptionsUI
{
@@ -28,13 +28,13 @@ class KafkaSyncOptions : public KafkaSyncOptionsUI
public:
- KafkaSyncOptions( KConfig *config, TQWidget* parent = 0, const char* name = 0);
+ KafkaSyncOptions( TDEConfig *config, TQWidget* parent = 0, const char* name = 0);
~KafkaSyncOptions();
void updateConfig();
protected:
- KConfig *config;
+ TDEConfig *config;
};
#endif
diff --git a/quanta/parts/kafka/nodeenhancer.h b/quanta/parts/kafka/nodeenhancer.h
index 44fd2e59..4fca17e1 100644
--- a/quanta/parts/kafka/nodeenhancer.h
+++ b/quanta/parts/kafka/nodeenhancer.h
@@ -18,7 +18,7 @@
#ifndef NODEENHANCER_H
#define NODEENHANCER_H
-class KConfig;
+class TDEConfig;
class Node;
namespace DOM
{
@@ -66,7 +66,7 @@ public:
* Read the config.
* @m_config The config to read.
*/
- virtual void readConfig(KConfig *m_config) = 0;
+ virtual void readConfig(TDEConfig *m_config) = 0;
/**
* This need to be strongly extended.
diff --git a/quanta/parts/kafka/undoredo.cpp b/quanta/parts/kafka/undoredo.cpp
index d21129cd..e788a5c7 100644
--- a/quanta/parts/kafka/undoredo.cpp
+++ b/quanta/parts/kafka/undoredo.cpp
@@ -190,7 +190,7 @@ void undoRedo::addNewModifsSet(NodeModifsSet *modifs, int modifLocation, NodeSel
return;
}
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
config->setGroup("Kate Document Defaults");
int indentationWidth = config->readNumEntry("Indentation Width", 4);
diff --git a/quanta/parts/kafka/wkafkapart.cpp b/quanta/parts/kafka/wkafkapart.cpp
index 8880dd27..39cefc8f 100644
--- a/quanta/parts/kafka/wkafkapart.cpp
+++ b/quanta/parts/kafka/wkafkapart.cpp
@@ -1796,7 +1796,7 @@ DOM::Node KafkaDocument::getNextSiblingNSpecial(DOM::Node domNode)
return DOM::Node();
}
-void KafkaDocument::readConfig(KConfig *m_config)
+void KafkaDocument::readConfig(TDEConfig *m_config)
{
#ifdef LIGHT_DEBUG
kdDebug(25001)<< "KafkaDocument::readConfig()" << endl;
diff --git a/quanta/parts/kafka/wkafkapart.h b/quanta/parts/kafka/wkafkapart.h
index 2d03477b..9c4f3529 100644
--- a/quanta/parts/kafka/wkafkapart.h
+++ b/quanta/parts/kafka/wkafkapart.h
@@ -18,7 +18,7 @@
#ifndef WKAFKAPART_H
#define WKAFKAPART_H
-class KConfig;
+class TDEConfig;
namespace DOM
{
class Node;
@@ -349,7 +349,7 @@ public:
* Read the config.
* @param m_config The config to read.
*/
- void readConfig(KConfig *m_config);
+ void readConfig(TDEConfig *m_config);
/**
* Returns the default DTD of the current Document.
diff --git a/quanta/parts/preview/whtmlpart.cpp b/quanta/parts/preview/whtmlpart.cpp
index 42af2d0c..e86a9203 100644
--- a/quanta/parts/preview/whtmlpart.cpp
+++ b/quanta/parts/preview/whtmlpart.cpp
@@ -40,7 +40,7 @@ WHTMLPart::WHTMLPart(TQWidget *parentWidget, const char *widgetName, bool enable
//kdDebug(24000) << "WHTMLPart: " << parentWidget << " " << widgetName << " " << parent << " " << name << this << endl;
hpos = 0;
// get settings from konq.
- KConfig konqConfig("konquerorrc");
+ TDEConfig konqConfig("konquerorrc");
konqConfig.setGroup("HTML Settings");
diff --git a/quanta/plugins/quantaplugininterface.cpp b/quanta/plugins/quantaplugininterface.cpp
index 098c7828..fc9a8823 100644
--- a/quanta/plugins/quantaplugininterface.cpp
+++ b/quanta/plugins/quantaplugininterface.cpp
@@ -56,7 +56,7 @@ QuantaPluginInterface::~QuantaPluginInterface()
void QuantaPluginInterface::readConfigFile(const TQString& configFile)
{
- KConfig *config = new KConfig(configFile);
+ TDEConfig *config = new TDEConfig(configFile);
config->setGroup("General");
TQStringList pList = config->readListEntry("Plugins");
for(TQStringList::Iterator it = pList.begin();it != pList.end(); ++it)
@@ -133,7 +133,7 @@ void QuantaPluginInterface::readConfig()
void QuantaPluginInterface::writeConfig()
{
// write the plugin settings to the rc file
- KConfig *config = new KConfig(locateLocal("appdata", "plugins.rc"));
+ TDEConfig *config = new TDEConfig(locateLocal("appdata", "plugins.rc"));
TQStringList names = pluginNames();
diff --git a/quanta/project/project.cpp b/quanta/project/project.cpp
index aed1942e..3e29c099 100644
--- a/quanta/project/project.cpp
+++ b/quanta/project/project.cpp
@@ -167,7 +167,7 @@ void Project::insertFile(const KURL& nameURL, bool repaint )
}
-void Project::readConfig(KConfig *config)
+void Project::readConfig(TDEConfig *config)
{
d->config = config;
config->setGroup("General Options");
@@ -209,10 +209,10 @@ void Project::loadLastProject(bool reload)
TQString tempPath = tempList[0];
TQString sessionTempPath = sessionTempList[0];
// test if the remote project is available
- if ( KIO::NetAccess::exists(url, false, d->m_mainWindow) )
+ if ( TDEIO::NetAccess::exists(url, false, d->m_mainWindow) )
{
KURL tempURL = KURL().fromPathOrURL(tempPath);
- if (KIO::NetAccess::exists(tempURL, false, d->m_mainWindow) &&
+ if (TDEIO::NetAccess::exists(tempURL, false, d->m_mainWindow) &&
KMessageBox::questionYesNo(d->m_mainWindow, i18n("<qt>Found a backup for project <b>%1</b>.<br> Do you want to open it?</qt>").arg(url.prettyURL()), i18n("Open Project Backup"), KStdGuiItem::open(), i18n("Do Not Open") )
== KMessageBox::Yes)
{
@@ -448,7 +448,7 @@ void Project::slotRemove(const KURL& urlToRemove)
TQString passwd = password(e.attribute("remote_protocol") + "://" + e.attribute("user") + "@" + e.attribute("remote_host"));
baseUrl.setPass(passwd);
baseUrl.addPath(urlPath);
- KIO::NetAccess::del(baseUrl, d->m_mainWindow);
+ TDEIO::NetAccess::del(baseUrl, d->m_mainWindow);
}
}
}
@@ -997,7 +997,7 @@ KURL Project::projectBaseURL()
void Project::savePassword(const TQString &entry, const TQString &passwd, bool store)
{
d->m_passwdList[entry] = passwd;
- KConfig *config = kapp->config();
+ TDEConfig *config = kapp->config();
config->setGroup("Projects");
if (store)
{
@@ -1017,7 +1017,7 @@ TQString Project::password(const TQString &entry)
return d->m_passwdList[entry];
else
{
- KConfig *config = kapp->config();
+ TDEConfig *config = kapp->config();
config->setGroup("Projects");
TQString passwd = KStringHandler::obscure(config->readEntry(d->projectName + " | " + entry,""));
// TQString passwd = config->readEntry(d->projectName + " | " + entry,"");
@@ -1027,7 +1027,7 @@ TQString Project::password(const TQString &entry)
bool Project::passwordSaved(const TQString &entry)
{
- KConfig *config = kapp->config();
+ TDEConfig *config = kapp->config();
config->setGroup("Projects");
TQString passwd = KStringHandler::obscure(config->readEntry(d->projectName + " | " + entry,""));
// TQString passwd = config->readEntry(d->projectName + " | " + entry,"");
diff --git a/quanta/project/project.h b/quanta/project/project.h
index 9014d16f..42d18fef 100644
--- a/quanta/project/project.h
+++ b/quanta/project/project.h
@@ -36,7 +36,7 @@ typedef TQMap<TQString, TQValueList<EventAction> > EventActions;
*@author Yacovlev Alexander & Dmitry Poplavsky & Andras Mantia & Jens Herden
*/
-class KConfig;
+class TDEConfig;
class KMainWindow;
struct TeamMember {
@@ -80,7 +80,7 @@ public:
KURL::List files();
void insertFile( const KURL& nameURL, bool repaint );
- void readConfig(KConfig *);
+ void readConfig(TDEConfig *);
/** loads the last project again if reload == true
but checks in any case if there is a left over project from a crash
*/
diff --git a/quanta/project/projectnewlocal.cpp b/quanta/project/projectnewlocal.cpp
index fb67e4fb..97d824f4 100644
--- a/quanta/project/projectnewlocal.cpp
+++ b/quanta/project/projectnewlocal.cpp
@@ -352,7 +352,7 @@ void ProjectNewLocal::slotClearList()
//Really wondering why would we delete the files from baseURL???
//I've added this code, but I don't remember the reason. :-(
//Anyway, it is quite evil thing to do.
- //KIO::del( baseURL );
+ //TDEIO::del( baseURL );
listView->clear();
fileList.clear();
checkInsert->setChecked(false);
diff --git a/quanta/project/projectprivate.cpp b/quanta/project/projectprivate.cpp
index fd49f0ce..096ef83f 100644
--- a/quanta/project/projectprivate.cpp
+++ b/quanta/project/projectprivate.cpp
@@ -1010,7 +1010,7 @@ bool ProjectPrivate::createEmptyDom()
tempFile->close();
result = QExtFileInfo::createDir(baseURL, m_mainWindow);
if (result)
- result = KIO::NetAccess::upload(tempFile->name(), projectURL, m_mainWindow);
+ result = TDEIO::NetAccess::upload(tempFile->name(), projectURL, m_mainWindow);
if (result)
m_tmpProjectFile = tempFile->name();
@@ -1019,7 +1019,7 @@ bool ProjectPrivate::createEmptyDom()
sessionTempFile->textStream()->setEncoding(TQTextStream::UnicodeUTF8);
*(sessionTempFile->textStream()) << sessionStr;
sessionTempFile->close();
- result = KIO::NetAccess::upload(sessionTempFile->name(), sessionURL, m_mainWindow);
+ result = TDEIO::NetAccess::upload(sessionTempFile->name(), sessionURL, m_mainWindow);
if (result)
m_tmpSessionFile= sessionTempFile->name();
} else
@@ -1364,8 +1364,8 @@ bool ProjectPrivate::loadProject(const KURL &url)
TQString sessionTmpFile;
// test if url is writeable and download to local file
- if (KIO::NetAccess::exists(url, false, m_mainWindow) &&
- KIO::NetAccess::download(url, projectTmpFile, m_mainWindow))
+ if (TDEIO::NetAccess::exists(url, false, m_mainWindow) &&
+ TDEIO::NetAccess::download(url, projectTmpFile, m_mainWindow))
{
if (parent->hasProject())
{
@@ -1378,8 +1378,8 @@ bool ProjectPrivate::loadProject(const KURL &url)
else
fileName += ".session";
sessionURL.setFileName(fileName);
- if (KIO::NetAccess::exists(sessionURL, false, m_mainWindow))
- KIO::NetAccess::download(sessionURL, sessionTmpFile, m_mainWindow);
+ if (TDEIO::NetAccess::exists(sessionURL, false, m_mainWindow))
+ TDEIO::NetAccess::download(sessionURL, sessionTmpFile, m_mainWindow);
else
{
TQString sessionStr;
@@ -1635,7 +1635,7 @@ bool ProjectPrivate::uploadProjectFile()
m_tmpProjectFile = TQString();
return true;
}
- if (KIO::NetAccess::upload(m_tmpProjectFile, projectURL, m_mainWindow) && KIO::NetAccess::upload(m_tmpSessionFile, sessionURL, m_mainWindow))
+ if (TDEIO::NetAccess::upload(m_tmpProjectFile, projectURL, m_mainWindow) && TDEIO::NetAccess::upload(m_tmpSessionFile, sessionURL, m_mainWindow))
{
removeFromConfig(projectURL.url()); // remove the project from the list of open projects
if (quantaApp)
@@ -1647,11 +1647,11 @@ bool ProjectPrivate::uploadProjectFile()
delete sessionTempFile;
sessionTempFile = 0L;
// second the one from downloading a project
- KIO::NetAccess::removeTempFile(m_tmpProjectFile);
- KIO::NetAccess::removeTempFile(m_tmpSessionFile);
+ TDEIO::NetAccess::removeTempFile(m_tmpProjectFile);
+ TDEIO::NetAccess::removeTempFile(m_tmpSessionFile);
// third if we recovered after crash
- KIO::NetAccess::del(KURL().fromPathOrURL(m_tmpProjectFile), m_mainWindow);
- KIO::NetAccess::del(KURL().fromPathOrURL(m_tmpSessionFile), m_mainWindow);
+ TDEIO::NetAccess::del(KURL().fromPathOrURL(m_tmpProjectFile), m_mainWindow);
+ TDEIO::NetAccess::del(KURL().fromPathOrURL(m_tmpSessionFile), m_mainWindow);
m_tmpProjectFile = "";
m_tmpSessionFile = "";
}
@@ -1660,7 +1660,7 @@ bool ProjectPrivate::uploadProjectFile()
if (quantaApp)
{
parent->statusMsg(TQString() );
- KMessageBox::error(m_mainWindow, KIO::NetAccess::lastErrorString());
+ KMessageBox::error(m_mainWindow, TDEIO::NetAccess::lastErrorString());
}
return false;
}
diff --git a/quanta/project/projectprivate.h b/quanta/project/projectprivate.h
index aa01a91d..0b0a14df 100644
--- a/quanta/project/projectprivate.h
+++ b/quanta/project/projectprivate.h
@@ -32,7 +32,7 @@ class TQWidgetStack;
class KAction;
class KActionCollection;
-class KConfig;
+class TDEConfig;
class KDirWatch;
class KRecentFilesAction;
class KSelectAction;
@@ -83,7 +83,7 @@ upload.*/
TQWidgetStack *stack;
TQString currentProjectView;
- KConfig *config;
+ TDEConfig *config;
bool m_modified;
bool m_excludeCvsignore;
/** Default DTD for this project. */
diff --git a/quanta/project/projectupload.cpp b/quanta/project/projectupload.cpp
index f38cf937..1f389cb4 100644
--- a/quanta/project/projectupload.cpp
+++ b/quanta/project/projectupload.cpp
@@ -158,7 +158,7 @@ void ProjectUpload::slotBuildTree()
{
emit eventHappened("upload_requested", m_project->projectBaseURL().url(), "");
loadRemoteUploadInfo();
- KIO::UDSEntry entry;
+ TDEIO::UDSEntry entry;
TQString strUrl = QuantaCommon::qUrl(startUrl);
bool isDirectory = strUrl.endsWith("/");
bool forceUpload = !startUrl.isEmpty();
@@ -209,7 +209,7 @@ void ProjectUpload::slotBuildTree()
int uploadedTime = -1;
if (m_uploadTimeList.contains(s))
uploadedTime = m_uploadTimeList[s];
- int modifiedTime = item.time(KIO::UDS_MODIFICATION_TIME);
+ int modifiedTime = item.time(TDEIO::UDS_MODIFICATION_TIME);
el.setAttribute("modified_time", modifiedTime);
int uploadStatus = el.attribute("uploadstatus", "1").toInt();
if (m_quickUpload || (forceUpload && uploadStatus == 0))
@@ -454,14 +454,14 @@ void ProjectUpload::upload()
if (!from.fileName(false).isEmpty() && fileItem)
{
emit eventHappened("before_upload", from.url(), to.url());
- KIO::FileCopyJob *job = KIO::file_copy( from, to, fileItem->permissions(), true, false, false );
+ TDEIO::FileCopyJob *job = TDEIO::file_copy( from, to, fileItem->permissions(), true, false, false );
- connect( job, TQT_SIGNAL( result( KIO::Job * ) ),this,
- TQT_SLOT( uploadFinished( KIO::Job * ) ) );
- connect( job, TQT_SIGNAL( percent( KIO::Job *,unsigned long ) ),
- this, TQT_SLOT( uploadProgress( KIO::Job *,unsigned long ) ) );
- connect( job, TQT_SIGNAL( infoMessage( KIO::Job *,const TQString& ) ),
- this, TQT_SLOT( uploadMessage( KIO::Job *,const TQString& ) ) );
+ connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),this,
+ TQT_SLOT( uploadFinished( TDEIO::Job * ) ) );
+ connect( job, TQT_SIGNAL( percent( TDEIO::Job *,unsigned long ) ),
+ this, TQT_SLOT( uploadProgress( TDEIO::Job *,unsigned long ) ) );
+ connect( job, TQT_SIGNAL( infoMessage( TDEIO::Job *,const TQString& ) ),
+ this, TQT_SLOT( uploadMessage( TDEIO::Job *,const TQString& ) ) );
labelCurFile->setText(i18n("Current: %1").arg(currentURL.fileName()));
currentProgress->setProgress( 0 );
@@ -477,7 +477,7 @@ void ProjectUpload::upload()
reject();
}
-void ProjectUpload::uploadFinished( KIO::Job *job )
+void ProjectUpload::uploadFinished( TDEIO::Job *job )
{
if ( !job ) return;
@@ -489,18 +489,18 @@ void ProjectUpload::uploadFinished( KIO::Job *job )
saveRemoteUploadInfo();
return;
}
- KIO::FileCopyJob *fJob = dynamic_cast<KIO::FileCopyJob *>(job);
+ TDEIO::FileCopyJob *fJob = dynamic_cast<TDEIO::FileCopyJob *>(job);
if (fJob)
emit eventHappened("after_upload", fJob->srcURL().url(), fJob->destURL().url());
slotUploadNext();
}
-void ProjectUpload::uploadProgress ( KIO::Job *, unsigned long percent )
+void ProjectUpload::uploadProgress ( TDEIO::Job *, unsigned long percent )
{
currentProgress->setProgress( percent );
}
-void ProjectUpload::uploadMessage ( KIO::Job *, const TQString & msg )
+void ProjectUpload::uploadMessage ( TDEIO::Job *, const TQString & msg )
{
labelCurFile->setText( currentURL.fileName() + " : " + msg );
}
diff --git a/quanta/project/projectupload.h b/quanta/project/projectupload.h
index 473f3e7e..bd341eec 100644
--- a/quanta/project/projectupload.h
+++ b/quanta/project/projectupload.h
@@ -56,9 +56,9 @@ public slots: // Public slots
protected slots:
void startUpload();
void upload();
- void uploadFinished( KIO::Job *job );
- void uploadProgress ( KIO::Job *job, unsigned long percent );
- void uploadMessage ( KIO::Job *, const TQString & msg );
+ void uploadFinished( TDEIO::Job *job );
+ void uploadProgress ( TDEIO::Job *job, unsigned long percent );
+ void uploadMessage ( TDEIO::Job *, const TQString & msg );
void slotUploadNext();
void clearSelection();
diff --git a/quanta/project/rescanprj.cpp b/quanta/project/rescanprj.cpp
index daa628a5..5f5ebc71 100644
--- a/quanta/project/rescanprj.cpp
+++ b/quanta/project/rescanprj.cpp
@@ -53,13 +53,13 @@ RescanPrj::RescanPrj(const ProjectList &p_prjFileList, const KURL& p_baseURL, co
excludeRx = p_excludeRx;
progressText->setText(i18n("Reading folder:"));
- KIO::ListJob *job = KIO::listRecursive( baseURL, false );
+ TDEIO::ListJob *job = TDEIO::listRecursive( baseURL, false );
m_listJobCount = 1;
- connect( job, TQT_SIGNAL(entries(KIO::Job *,const KIO::UDSEntryList &)),
- this,TQT_SLOT (addEntries(KIO::Job *,const KIO::UDSEntryList &)));
- connect( job, TQT_SIGNAL(result(KIO::Job *)),
- this,TQT_SLOT (slotListDone(KIO::Job *)));
+ connect( job, TQT_SIGNAL(entries(TDEIO::Job *,const TDEIO::UDSEntryList &)),
+ this,TQT_SLOT (addEntries(TDEIO::Job *,const TDEIO::UDSEntryList &)));
+ connect( job, TQT_SIGNAL(result(TDEIO::Job *)),
+ this,TQT_SLOT (slotListDone(TDEIO::Job *)));
connect( buttonSelect, TQT_SIGNAL(clicked()),
@@ -83,16 +83,16 @@ RescanPrj::~RescanPrj()
urlList.clear();
}
-void RescanPrj::addEntries(KIO::Job *job,const KIO::UDSEntryList &list)
+void RescanPrj::addEntries(TDEIO::Job *job,const TDEIO::UDSEntryList &list)
{
- KURL url = static_cast<KIO::ListJob *>(job)->url();
+ KURL url = static_cast<TDEIO::ListJob *>(job)->url();
url.adjustPath(-1);
// avoid creating these TQStrings again and again
static const TQString& dot = TDEGlobal::staticQString(".");
static const TQString& dotdot = TDEGlobal::staticQString("..");
- KIO::UDSEntryListConstIterator it = list.begin();
- KIO::UDSEntryListConstIterator end = list.end();
+ TDEIO::UDSEntryListConstIterator it = list.begin();
+ TDEIO::UDSEntryListConstIterator end = list.end();
KURL itemURL;
URLListEntry urlEntry;
TQString name;
@@ -148,13 +148,13 @@ void RescanPrj::addEntries(KIO::Job *job,const KIO::UDSEntryList &list)
}
for (TQPtrList<KFileItem>::ConstIterator it = linkItems.constBegin(); it != linkItems.constEnd(); ++it)
{
- KIO::ListJob *ljob = KIO::listRecursive( (*it)->url(), false );
+ TDEIO::ListJob *ljob = TDEIO::listRecursive( (*it)->url(), false );
m_listJobCount++;
- connect( ljob, TQT_SIGNAL(entries(KIO::Job *,const KIO::UDSEntryList &)),
- this,TQT_SLOT (addEntries(KIO::Job *,const KIO::UDSEntryList &)));
- connect( ljob, TQT_SIGNAL(result(KIO::Job *)),
- this,TQT_SLOT (slotListDone(KIO::Job *)));
+ connect( ljob, TQT_SIGNAL(entries(TDEIO::Job *,const TDEIO::UDSEntryList &)),
+ this,TQT_SLOT (addEntries(TDEIO::Job *,const TDEIO::UDSEntryList &)));
+ connect( ljob, TQT_SIGNAL(result(TDEIO::Job *)),
+ this,TQT_SLOT (slotListDone(TDEIO::Job *)));
}
}
@@ -220,7 +220,7 @@ KURL::List RescanPrj::files()
return r;
}
/** No descriptions */
-void RescanPrj::slotListDone(KIO::Job *)
+void RescanPrj::slotListDone(TDEIO::Job *)
{
m_listJobCount--;
// kdDebug(24000) << "slotListDone " << m_listJobCount << endl;
diff --git a/quanta/project/rescanprj.h b/quanta/project/rescanprj.h
index bfc7b635..da3844ac 100644
--- a/quanta/project/rescanprj.h
+++ b/quanta/project/rescanprj.h
@@ -51,7 +51,7 @@ public slots:
KURL::List files();
- void addEntries(KIO::Job *,const KIO::UDSEntryList &);
+ void addEntries(TDEIO::Job *,const TDEIO::UDSEntryList &);
private:
KURL baseURL;
@@ -62,7 +62,7 @@ private:
protected slots: // Protected slots
/** No descriptions */
- void slotListDone(KIO::Job *);
+ void slotListDone(TDEIO::Job *);
};
#endif
diff --git a/quanta/quanta_uml.xmi b/quanta/quanta_uml.xmi
index b2c7001b..5a384a85 100644
--- a/quanta/quanta_uml.xmi
+++ b/quanta/quanta_uml.xmi
@@ -147,7 +147,7 @@
<UML:Attribute stereotype="" package="" xmi.id="115" value="" type="KDockWidget *" abstract="0" documentation="" name="bottdock" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="116" value="" type="QWidgetStack *" abstract="0" documentation="" name="bottomWidgetStack" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="117" value="" type="KAction *" abstract="0" documentation="" name="closeprjAction" static="0" scope="201" />
- <UML:Attribute stereotype="" package="" xmi.id="118" value="" type="KConfig *" abstract="0" documentation="" name="config" static="0" scope="201" />
+ <UML:Attribute stereotype="" package="" xmi.id="118" value="" type="TDEConfig *" abstract="0" documentation="" name="config" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="119" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="currentToolbarDTD" static="0" scope="202" />
<UML:Attribute stereotype="" package="" xmi.id="120" value="" type="DocTreeView *" abstract="0" documentation="" name="dTab" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="121" value="" type="PHP3Debugger *" abstract="0" documentation="" name="dbg3" static="0" scope="201" />
@@ -261,7 +261,7 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="293" type="void" abstract="0" documentation="" name="prevDocument" static="0" scope="200" />
<UML:Operation stereotype="" package="" xmi.id="294" type="void" abstract="0" documentation="" name="readConfig" static="0" scope="200" >
- <UML:Parameter stereotype="" package="" xmi.id="295" value="" type="KConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="295" value="" type="TDEConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="296" type="bool" abstract="0" documentation="" name="saveAll" static="0" scope="200" >
<UML:Parameter stereotype="" package="" xmi.id="297" value="" type="bool" abstract="0" documentation="" name="dont_ask" static="0" scope="200" />
@@ -275,7 +275,7 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="303" type="Document *" abstract="0" documentation="" name="write" static="0" scope="200" />
<UML:Operation stereotype="" package="" xmi.id="304" type="void" abstract="0" documentation="" name="writeConfig" static="0" scope="200" >
- <UML:Parameter stereotype="" package="" xmi.id="305" value="" type="KConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="305" value="" type="TDEConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="306" type="" abstract="0" documentation="" name="~QuantaDoc" static="0" scope="200" />
<UML:Attribute stereotype="" package="" xmi.id="275" value="" type="KPopupMenu *" abstract="0" documentation="" name="attribMenu" static="0" scope="201" />
@@ -519,7 +519,7 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Operation stereotype="" package="" xmi.id="509" type="void" abstract="0" documentation="" name="parseVariables" static="0" scope="200" />
<UML:Operation stereotype="" package="" xmi.id="510" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="parsingDTD" static="0" scope="200" />
<UML:Operation stereotype="" package="" xmi.id="511" type="void" abstract="0" documentation="" name="readConfig" static="0" scope="200" >
- <UML:Parameter stereotype="" package="" xmi.id="512" value="" type="KConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="512" value="" type="TDEConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="513" type="void" abstract="0" documentation="" name="replaceSelected" static="0" scope="200" >
<UML:Parameter stereotype="" package="" xmi.id="514" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="s" static="0" scope="200" />
@@ -573,7 +573,7 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="551" type="KURL" abstract="0" documentation="" name="url" static="0" scope="200" />
<UML:Operation stereotype="" package="" xmi.id="552" type="void" abstract="0" documentation="" name="writeConfig" static="0" scope="200" >
- <UML:Parameter stereotype="" package="" xmi.id="553" value="" type="KConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="553" value="" type="TDEConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="554" type="bool" abstract="0" documentation="" name="xmlAutoCompletion" static="0" scope="202" >
<UML:Parameter stereotype="" package="" xmi.id="555" value="" type="DTDStruct *" abstract="0" documentation="" name="" static="0" scope="200" />
@@ -875,13 +875,13 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Parameter stereotype="" package="" xmi.id="777" value="" type="uint &amp;" abstract="0" documentation="" name="col" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="778" type="void" abstract="0" documentation="" name="readConfig" static="0" scope="200" >
- <UML:Parameter stereotype="" package="" xmi.id="779" value="" type="KConfig *" abstract="0" documentation="" name="config" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="779" value="" type="TDEConfig *" abstract="0" documentation="" name="config" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="780" type="void" abstract="0" documentation="" name="spellCheck" static="0" scope="200" >
<UML:Parameter stereotype="" package="" xmi.id="781" value="" type="KTextEditor :: Document *" abstract="0" documentation="" name="document" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="782" type="void" abstract="0" documentation="" name="writeConfig" static="0" scope="200" >
- <UML:Parameter stereotype="" package="" xmi.id="783" value="" type="KConfig *" abstract="0" documentation="" name="config" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="783" value="" type="TDEConfig *" abstract="0" documentation="" name="config" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="784" type="" abstract="0" documentation="" name="~SpellChecker" static="0" scope="200" />
<UML:Attribute stereotype="" package="" xmi.id="768" value="" type="KSpell *" abstract="0" documentation="" name="m_kspell" static="0" scope="201" />
@@ -1024,10 +1024,10 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Operation stereotype="" package="" xmi.id="924" type="virtual const QString &amp;" abstract="0" documentation="" name="newFileType" static="0" scope="200" />
<UML:Operation stereotype="" package="" xmi.id="925" type="void" abstract="0" documentation="" name="openCurrentView" static="0" scope="202" />
<UML:Operation stereotype="" package="" xmi.id="926" type="void" abstract="0" documentation="" name="readConfig" static="0" scope="200" >
- <UML:Parameter stereotype="" package="" xmi.id="927" value="" type="KConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="927" value="" type="TDEConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="928" type="void" abstract="0" documentation="" name="readLastConfig" static="0" scope="200" >
- <UML:Parameter stereotype="" package="" xmi.id="929" value="" type="KConfig *" abstract="0" documentation="" name="c" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="929" value="" type="TDEConfig *" abstract="0" documentation="" name="c" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="930" type="virtual void" abstract="0" documentation="" name="setDefaultDTD" static="0" scope="200" >
<UML:Parameter stereotype="" package="" xmi.id="931" value="" type="const QString &amp;" abstract="0" documentation="" name="p_defaultDTD" static="0" scope="200" />
@@ -1036,13 +1036,13 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Parameter stereotype="" package="" xmi.id="933" value="" type="const KURL &amp;" abstract="0" documentation="" name="url" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="934" type="void" abstract="0" documentation="" name="writeConfig" static="0" scope="200" >
- <UML:Parameter stereotype="" package="" xmi.id="935" value="" type="KConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="935" value="" type="TDEConfig *" abstract="0" documentation="" name="" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="936" type="" abstract="0" documentation="" name="~Project" static="0" scope="200" />
<UML:Attribute stereotype="" package="" xmi.id="877" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="author" static="0" scope="200" />
<UML:Attribute stereotype="" package="" xmi.id="878" value="" type="KURL" abstract="0" documentation="" name="baseURL" static="0" scope="200" />
<UML:Attribute stereotype="" package="" xmi.id="879" value="" type="QBuffer" abstract="0" documentation="" name="buff" static="0" scope="201" />
- <UML:Attribute stereotype="" package="" xmi.id="880" value="" type="KConfig *" abstract="0" documentation="" name="config" static="0" scope="201" />
+ <UML:Attribute stereotype="" package="" xmi.id="880" value="" type="TDEConfig *" abstract="0" documentation="" name="config" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="881" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="currentProjectView" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="882" value="" type="QDomDocument" abstract="0" documentation="" name="dom" static="0" scope="200" />
<UML:Attribute stereotype="" package="" xmi.id="883" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="email" static="0" scope="200" />
@@ -1171,13 +1171,13 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Operation stereotype="" package="" xmi.id="1017" type="" abstract="0" documentation="" name="DocFolder" static="0" scope="200" >
<UML:Parameter stereotype="" package="" xmi.id="1018" value="" type="QListView *" abstract="0" documentation="" name="parent" static="0" scope="200" />
<UML:Parameter stereotype="" package="" xmi.id="1019" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="_name" static="0" scope="200" />
- <UML:Parameter stereotype="" package="" xmi.id="1020" value="" type="KConfig *" abstract="0" documentation="" name="config" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="1020" value="" type="TDEConfig *" abstract="0" documentation="" name="config" static="0" scope="200" />
<UML:Parameter stereotype="" package="" xmi.id="1021" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="basePath" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="1022" type="" abstract="0" documentation="" name="DocFolder" static="0" scope="200" >
<UML:Parameter stereotype="" package="" xmi.id="1023" value="" type="QListViewItem *" abstract="0" documentation="" name="parent" static="0" scope="200" />
<UML:Parameter stereotype="" package="" xmi.id="1024" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="_name" static="0" scope="200" />
- <UML:Parameter stereotype="" package="" xmi.id="1025" value="" type="KConfig *" abstract="0" documentation="" name="config" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="1025" value="" type="TDEConfig *" abstract="0" documentation="" name="config" static="0" scope="200" />
<UML:Parameter stereotype="" package="" xmi.id="1026" value="" type=TQSTRING_OBJECT_NAME_STRING abstract="0" documentation="" name="basePath" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="1027" type="void" abstract="0" documentation="" name="setOpen" static="0" scope="200" >
@@ -1318,7 +1318,7 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Class stereotype="" package="" xmi.id="1126" abstract="0" documentation="Treeview to display the document structure. Inherits from KListView." name="StructTreeView" static="0" scope="200" >
<UML:Operation stereotype="" package="" xmi.id="1144" type="" abstract="0" documentation="" name="StructTreeView" static="0" scope="200" >
<UML:Parameter stereotype="" package="" xmi.id="1145" value="" type="Parser *" abstract="0" documentation="" name="parser" static="0" scope="200" />
- <UML:Parameter stereotype="" package="" xmi.id="1146" value="" type="KConfig *" abstract="0" documentation="" name="config" static="0" scope="200" />
+ <UML:Parameter stereotype="" package="" xmi.id="1146" value="" type="TDEConfig *" abstract="0" documentation="" name="config" static="0" scope="200" />
<UML:Parameter stereotype="" package="" xmi.id="1147" value="" type="QWidget *" abstract="0" documentation="" name="parent" static="0" scope="200" />
<UML:Parameter stereotype="" package="" xmi.id="1148" value="" type="const char *" abstract="0" documentation="" name="name" static="0" scope="200" />
</UML:Operation>
@@ -1346,7 +1346,7 @@ See the operations in order to get a picture what's here." name="QuantaDoc" stat
<UML:Parameter stereotype="" package="" xmi.id="1165" value="" type="int" abstract="0" documentation="" name="y" static="0" scope="200" />
</UML:Operation>
<UML:Operation stereotype="" package="" xmi.id="1166" type="" abstract="0" documentation="" name="~StructTreeView" static="0" scope="200" />
- <UML:Attribute stereotype="" package="" xmi.id="1127" value="" type="KConfig *" abstract="0" documentation="" name="config" static="0" scope="201" />
+ <UML:Attribute stereotype="" package="" xmi.id="1127" value="" type="TDEConfig *" abstract="0" documentation="" name="config" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="1128" value="" type=TQSTRINGLIST_OBJECT_NAME_STRING abstract="0" documentation="" name="dtdList" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="1129" value="" type="QPopupMenu *" abstract="0" documentation="" name="dtdMenu" static="0" scope="201" />
<UML:Attribute stereotype="" package="" xmi.id="1130" value="" type="bool" abstract="0" documentation="" name="followCursorFlag" static="0" scope="201" />
diff --git a/quanta/src/document.cpp b/quanta/src/document.cpp
index c8a84ef4..2cec0c03 100644
--- a/quanta/src/document.cpp
+++ b/quanta/src/document.cpp
@@ -407,7 +407,7 @@ void Document::insertFile(const KURL& url)
fileName = url.path();
} else
{
- if (!KIO::NetAccess::download(url, fileName, this))
+ if (!TDEIO::NetAccess::download(url, fileName, this))
{
KMessageBox::error(this, i18n("<qt>Cannot download <b>%1</b>.</qt>").arg( url.prettyURL(0, KURL::StripFileProtocol)));
return;
@@ -2667,7 +2667,7 @@ void Document::setBackupPathEntryValue(const TQString& ev)
}
/** if the document is modified then backup it and insert an entry in quantarc */
-void Document::createBackup(KConfig* config)
+void Document::createBackup(TDEConfig* config)
{
if (isModified())
{
@@ -2715,7 +2715,7 @@ void Document::createBackup(KConfig* config)
}
}
/** if there is no more need for a backup copy then remove it */
-void Document::removeBackup(KConfig *config)
+void Document::removeBackup(TDEConfig *config)
{
TQString backupPathValueURL = KURL::fromPathOrURL(m_backupPathValue).url();
diff --git a/quanta/src/document.h b/quanta/src/document.h
index 8ed866c3..99511907 100644
--- a/quanta/src/document.h
+++ b/quanta/src/document.h
@@ -39,7 +39,7 @@ class TQEvent;
class TQFocusEvent;
class TQTextCodec;
class TQStringList;
-class KConfig;
+class TDEConfig;
class KTempFile;
class KURL;
class Tag;
@@ -218,13 +218,13 @@ work correctly. */
bool isBackedUp();
/** Creates an automatic backup copy for the crash recovering mechanism */
- void createBackup(KConfig* config);
+ void createBackup(TDEConfig* config);
/** No descriptions */
TQString backupPathEntryValue();
/** No descriptions */
void setBackupPathEntryValue(const TQString& ev);
/** Removes automatic backup copies */
- void removeBackup(KConfig *config);
+ void removeBackup(TDEConfig *config);
/** create a string using document path string */
static TQString hashFilePath(const TQString& p);
TQString annotationText(uint line);
diff --git a/quanta/src/dtds.cpp b/quanta/src/dtds.cpp
index 97ec6ec0..9a91f304 100644
--- a/quanta/src/dtds.cpp
+++ b/quanta/src/dtds.cpp
@@ -165,7 +165,7 @@ bool DTDs::readTagDir(const TQString &dirName, bool loadAll)
TQString tmpStr = dirName + m_rcFilename;
if (!TQFile::exists(tmpStr))
return false;
- KConfig *dtdConfig = new KConfig(tmpStr, true);
+ TDEConfig *dtdConfig = new TDEConfig(tmpStr, true);
dtdConfig->setGroup("General");
TQString dtdName = dtdConfig->readEntry("Name", "Unknown");
if (m_dict->find(dtdName.lower()))
@@ -241,7 +241,7 @@ bool DTDs::readTagDir2(DTDStruct *dtd)
kapp->setOverrideCursor( TQCursor(TQt::WaitCursor) );
- KConfig *dtdConfig = new KConfig(dtd->fileName, true);
+ TDEConfig *dtdConfig = new TDEConfig(dtd->fileName, true);
//read the general DTD info
dtdConfig->setGroup("General");
@@ -908,7 +908,7 @@ void DTDs::slotLoadDTD()
if (dtdParser.parse())
{
TQString dirName = dtdParser.dirName();
- KConfig dtdcfg(dirName + m_rcFilename, true);
+ TDEConfig dtdcfg(dirName + m_rcFilename, true);
dtdcfg.setGroup("General");
TQString dtdName = dtdcfg.readEntry("Name");
TQString nickName = dtdcfg.readEntry("NickName", dtdName);
@@ -940,7 +940,7 @@ void DTDs::slotLoadDTEP(const TQString &_dirName, bool askForAutoload)
TQString dirName = _dirName;
if (!dirName.endsWith("/"))
dirName += "/";
- KConfig dtdcfg(dirName + m_rcFilename, true);
+ TDEConfig dtdcfg(dirName + m_rcFilename, true);
dtdcfg.setGroup("General");
TQString dtdName = dtdcfg.readEntry("Name");
TQString nickName = dtdcfg.readEntry("NickName", dtdName);
@@ -964,7 +964,7 @@ void DTDs::slotLoadDTEP(const TQString &_dirName, bool askForAutoload)
KURL target;
TQString destDir = TDEGlobal::dirs()->saveLocation("data") + resourceDir + "dtep/";
target.setPath(destDir + src.fileName());
- KIO::copy( src, target, false); //don't care about the result
+ TDEIO::copy( src, target, false); //don't care about the result
}
Document *w = ViewManager::ref()->activeDocument();
if (family == "1" && w &&
diff --git a/quanta/src/dtds.h b/quanta/src/dtds.h
index e532a934..e1329b24 100644
--- a/quanta/src/dtds.h
+++ b/quanta/src/dtds.h
@@ -37,7 +37,7 @@ class TQDomDocument;
class TQTag;
class TQString;
class TQStringList;
-class KConfig;
+class TDEConfig;
struct DTDStruct;
diff --git a/quanta/src/kqapp.cpp b/quanta/src/kqapp.cpp
index 3b306f0f..33a68e91 100644
--- a/quanta/src/kqapp.cpp
+++ b/quanta/src/kqapp.cpp
@@ -77,7 +77,7 @@ KQApplication::KQApplication()
}
else */
{
- KConfig *config = kapp->config();
+ TDEConfig *config = kapp->config();
config->setGroup("General Options");
int mdiMode = config->readNumEntry("MDI mode", KMdi::IDEAlMode);
TQString layout = config->readEntry("Window layout", "Default");
@@ -148,7 +148,7 @@ int KQUniqueApplication::newInstance()
else
{
splash = 0L;
- KConfig *config = kapp->config();
+ TDEConfig *config = kapp->config();
config->setGroup("General Options");
int mdiMode = config->readNumEntry("MDI mode", KMdi::IDEAlMode);
TQString layout = config->readEntry("Window layout", "Default");
diff --git a/quanta/src/quanta.cpp b/quanta/src/quanta.cpp
index 434bff2f..cbcbfd50 100644
--- a/quanta/src/quanta.cpp
+++ b/quanta/src/quanta.cpp
@@ -302,7 +302,7 @@ QuantaApp::~QuantaApp()
tempFileList.clear();
for (uint i = 0; i < tempDirList.count(); i++)
{
- KIO::NetAccess::del(KURL().fromPathOrURL(tempDirList.at(i)->name()), this);
+ TDEIO::NetAccess::del(KURL().fromPathOrURL(tempDirList.at(i)->name()), this);
}
tempDirList.clear();
TQDictIterator<ToolbarEntry> iter(m_toolbarList);
@@ -879,7 +879,7 @@ void QuantaApp::slotInsertTag(const KURL& url, DirInfo dirInfo)
if (mimetype.contains("image"))
{
TQString imgFileName;
- KIO::NetAccess::download(url, imgFileName, this);
+ TDEIO::NetAccess::download(url, imgFileName, this);
TQImage img(imgFileName);
if (!img.isNull())
{
@@ -900,7 +900,7 @@ void QuantaApp::slotInsertTag(const KURL& url, DirInfo dirInfo)
w->insertTag(imgTag);
isImage = true;
}
- KIO::NetAccess::removeTempFile(imgFileName);
+ TDEIO::NetAccess::removeTempFile(imgFileName);
}
if (!isImage)
{
@@ -1414,7 +1414,7 @@ void QuantaApp::slotShowPreviewWidget(bool show)
{
KURL url = m_previewedDocument->url();
url.setFileName("preview-" + url.fileName());
- KIO::NetAccess::del(url, this);
+ TDEIO::NetAccess::del(url, this);
Document *w = view->document();
if (w)
w->view()->setFocus();
@@ -1452,7 +1452,7 @@ void QuantaApp::slotChangePreviewStatus()
{
KURL url = m_previewedDocument->url();
url.setFileName("preview-" + url.fileName());
- KIO::NetAccess::del(url, this);
+ TDEIO::NetAccess::del(url, this);
}
slotRepaintPreview();
m_previewedDocument = 0L;
@@ -1474,7 +1474,7 @@ void QuantaApp::slotPreviewHasFocus(bool focus)
{
KURL url = m_previewedDocument->url();
url.setFileName("preview-" + url.fileName());
- KIO::NetAccess::del(url, this);
+ TDEIO::NetAccess::del(url, this);
}
m_previewedDocument = 0L;
}
diff --git a/quanta/src/quanta.h b/quanta/src/quanta.h
index c701d25b..7140b51a 100644
--- a/quanta/src/quanta.h
+++ b/quanta/src/quanta.h
@@ -122,7 +122,7 @@ public:
QuantaDoc *doc() const {return m_doc; }
TQPopupMenu *tagsMenu() const {return m_tagsMenu;}
- KConfig *config() const {return m_config;}
+ TDEConfig *config() const {return m_config;}
//TODO: check if we really need these "get" methods (and get rid o get)
MessageOutput *messageOutput() const {return m_messageOutput;}
@@ -574,7 +574,7 @@ private:
TQPopupMenu *m_tagsMenu;
// config
- KConfig *m_config;
+ TDEConfig *m_config;
/** HTML class for preview */
WHTMLPart *m_htmlPart;
diff --git a/quanta/src/quanta_init.cpp b/quanta/src/quanta_init.cpp
index 73d6c858..974dbc92 100644
--- a/quanta/src/quanta_init.cpp
+++ b/quanta/src/quanta_init.cpp
@@ -691,7 +691,7 @@ void QuantaInit::loadInitialProject(const TQString& url)
if(runningQuantas() == 1)
{
// Get config
- KConfig *config = m_quanta->config();
+ TDEConfig *config = m_quanta->config();
config->setGroup("General Options");
// Reload last project if setting is enabled
@@ -1143,16 +1143,16 @@ void QuantaInit::recoverCrashed(TQStringList& recoveredFileNameList)
if (!isPrj || originalVersion.isLocalFile())
{
//find some information about local files
- KIO::UDSEntry entry;
- KIO::NetAccess::stat(originalVersion, entry, m_quanta);
+ TDEIO::UDSEntry entry;
+ TDEIO::NetAccess::stat(originalVersion, entry, m_quanta);
KFileItem* item= new KFileItem(entry, originalVersion, false, true);
TQString origTime = item->timeString();
- KIO::filesize_t origSize = item->size();
+ TDEIO::filesize_t origSize = item->size();
delete item;
- KIO::NetAccess::stat(autosavedVersion, entry, m_quanta);
+ TDEIO::NetAccess::stat(autosavedVersion, entry, m_quanta);
item= new KFileItem(entry, autosavedVersion, false, true);
TQString backupTime = item->timeString();
- KIO::filesize_t backupSize = item->size();
+ TDEIO::filesize_t backupSize = item->size();
delete item;
if (TQFileInfo(autosavedPath).exists()) //if the backup file exists
@@ -1169,8 +1169,8 @@ void QuantaInit::recoverCrashed(TQStringList& recoveredFileNameList)
"Backup created on: <b>%5</b><br><br>"
"</qt>")
.arg(originalVersion.prettyURL(0, KURL::StripFileProtocol ))
- .arg(KIO::convertSize(origSize)).arg(origTime)
- .arg(KIO::convertSize(backupSize)).arg(backupTime));
+ .arg(TDEIO::convertSize(origSize)).arg(origTime)
+ .arg(TDEIO::convertSize(backupSize)).arg(backupTime));
w->buttonLoad->setText(i18n("&Restore the file from backup"));
w->buttonIgnore->setText(i18n("Do &not restore the file from backup"));
delete w->warningLabel;
diff --git a/quanta/src/quanta_init.h b/quanta/src/quanta_init.h
index 196c723c..5ca93826 100644
--- a/quanta/src/quanta_init.h
+++ b/quanta/src/quanta_init.h
@@ -34,7 +34,7 @@ class ViewManager;
class ProjectTreeView;
class TemplatesTreeView;
class ScriptTreeView;
-class KConfig;
+class TDEConfig;
/**
* The base class for Quanta application windows.
@@ -91,7 +91,7 @@ private:
ProjectTreeView *pTab;
TemplatesTreeView *tTab;
// config
- KConfig *m_config;
+ TDEConfig *m_config;
TQStringList m_PIDlist;
/** @return number of Quanta instances registered by dcop */
int runningQuantas();
diff --git a/quanta/src/quantadoc.h b/quanta/src/quantadoc.h
index e40d1fa5..276c3a8c 100644
--- a/quanta/src/quantadoc.h
+++ b/quanta/src/quantadoc.h
@@ -22,7 +22,7 @@
// forward declaration of the Quanta classes
class Document;
-class KConfig;
+class TDEConfig;
class KURL;
class QuantaDoc : public TQObject
diff --git a/quanta/treeviews/basetreeview.cpp b/quanta/treeviews/basetreeview.cpp
index 278505a2..7ff962e1 100644
--- a/quanta/treeviews/basetreeview.cpp
+++ b/quanta/treeviews/basetreeview.cpp
@@ -669,7 +669,7 @@ void BaseTreeView::slotPaste()
}
-void BaseTreeView::slotPercent(KIO::Job *job, unsigned long value)
+void BaseTreeView::slotPercent(TDEIO::Job *job, unsigned long value)
{
Q_UNUSED(job);
progressBar->setProgress(value);
@@ -818,7 +818,7 @@ void BaseTreeView::reload(BaseTreeBranch *btb)
}
-void BaseTreeView::slotJobFinished(KIO::Job *job)
+void BaseTreeView::slotJobFinished(TDEIO::Job *job)
{
if ( job->error() )
job->showErrorDialog(this);
@@ -894,7 +894,7 @@ void BaseTreeView::slotDropped (TQWidget *, TQDropEvent * /*e*/, KURL::List& fil
}
}
bool tooltip = showToolTips();
- KIO::Job *job;
+ TDEIO::Job *job;
switch ( result ) {
case 1 : setShowToolTips(false);
setDragEnabled(false);
@@ -908,18 +908,18 @@ void BaseTreeView::slotDropped (TQWidget *, TQDropEvent * /*e*/, KURL::List& fil
setDragEnabled(true);
setShowToolTips(tooltip);
return;
- case 3 : job = KIO::link(fileList, dest);
+ case 3 : job = TDEIO::link(fileList, dest);
break;
default : return ;
}
if (!job)
return;
- connect(job, TQT_SIGNAL( result(KIO::Job *) ),
- this, TQT_SLOT( slotJobFinished(KIO::Job *) ) );
+ connect(job, TQT_SIGNAL( result(TDEIO::Job *) ),
+ this, TQT_SLOT( slotJobFinished(TDEIO::Job *) ) );
progressBar->setTotalSteps(100);
- connect(job, TQT_SIGNAL(percent( KIO::Job *, unsigned long)),
- this, TQT_SLOT(slotPercent( KIO::Job *, unsigned long)));
+ connect(job, TQT_SIGNAL(percent( TDEIO::Job *, unsigned long)),
+ this, TQT_SLOT(slotPercent( TDEIO::Job *, unsigned long)));
}
@@ -1057,13 +1057,13 @@ void BaseTreeView::doRename(KFileTreeViewItem* kftvi, const TQString & newName)
}
-void BaseTreeView::saveLayout(KConfig *config, const TQString &group)
+void BaseTreeView::saveLayout(TDEConfig *config, const TQString &group)
{
KListView::saveLayout(config, group);
if (! m_saveOpenFolder || ! qConfig.saveTrees)
return;
- KConfigGroupSaver saver(config, group);
+ TDEConfigGroupSaver saver(config, group);
BaseTreeBranch *btb;
int i = 0;
KFileTreeBranchIterator it( branches() );
@@ -1083,10 +1083,10 @@ void BaseTreeView::saveLayout(KConfig *config, const TQString &group)
}
-void BaseTreeView::restoreLayout(KConfig *config, const TQString &group)
+void BaseTreeView::restoreLayout(TDEConfig *config, const TQString &group)
{
KListView::restoreLayout(config, group);
- KConfigGroupSaver saver(config, group);
+ TDEConfigGroupSaver saver(config, group);
setShowToolTips( config->readBoolEntry("ShowToolTips", true) );
if (! m_saveOpenFolder || ! qConfig.saveTrees)
diff --git a/quanta/treeviews/docfolder.cpp b/quanta/treeviews/docfolder.cpp
index 0a1d941d..3e7e8949 100644
--- a/quanta/treeviews/docfolder.cpp
+++ b/quanta/treeviews/docfolder.cpp
@@ -28,7 +28,7 @@
#include "docfolder.h"
#include "docitem.h"
-DocFolder::DocFolder(TQListViewItem *parent, const TQString &_name, KConfig *config, const TQString &basePath)
+DocFolder::DocFolder(TQListViewItem *parent, const TQString &_name, TDEConfig *config, const TQString &basePath)
: KListViewItem(parent)
{
name = _name;
@@ -59,7 +59,7 @@ DocFolder::DocFolder(TQListViewItem *parent, const TQString &_name, KConfig *con
}
}
-DocFolder::DocFolder(TQListView *parent, const TQString &_name, KConfig *config, const TQString &basePath)
+DocFolder::DocFolder(TQListView *parent, const TQString &_name, TDEConfig *config, const TQString &basePath)
: KListViewItem(parent)
{
name = _name;
diff --git a/quanta/treeviews/docfolder.h b/quanta/treeviews/docfolder.h
index f3c8db87..5f36a825 100644
--- a/quanta/treeviews/docfolder.h
+++ b/quanta/treeviews/docfolder.h
@@ -29,12 +29,12 @@ Doc tree
*@author Yacovlev Alexander & Dmitry Poplavsky
*/
-class KConfig;
+class TDEConfig;
class DocFolder : public KListViewItem {
public:
- DocFolder(TQListViewItem *parent, const TQString &_name, KConfig *config, const TQString &basePath);
- DocFolder(TQListView *parent, const TQString &_name, KConfig *config, const TQString &basePath);
+ DocFolder(TQListViewItem *parent, const TQString &_name, TDEConfig *config, const TQString &basePath);
+ DocFolder(TQListView *parent, const TQString &_name, TDEConfig *config, const TQString &basePath);
~DocFolder();
TQString text( int column ) const;
void setup();
diff --git a/quanta/treeviews/docitem.h b/quanta/treeviews/docitem.h
index 59b126a1..6022650b 100644
--- a/quanta/treeviews/docitem.h
+++ b/quanta/treeviews/docitem.h
@@ -22,7 +22,7 @@
#include <klistview.h>
-class KConfig;
+class TDEConfig;
/**
*@author Yacovlev Alexander & Dmitry Poplavsky
diff --git a/quanta/treeviews/doctreeview.cpp b/quanta/treeviews/doctreeview.cpp
index 39d8ba5b..31579563 100644
--- a/quanta/treeviews/doctreeview.cpp
+++ b/quanta/treeviews/doctreeview.cpp
@@ -90,7 +90,7 @@ void DocTreeView::slotRefreshTree()
for ( TQStringList::Iterator it_f = files.begin(); it_f != files.end(); ++it_f )
{
- KConfig config( docDir + *it_f );
+ TDEConfig config( docDir + *it_f );
config.setGroup("Tree");
TQString relDocDir = config.readEntry("Doc dir");
diff --git a/quanta/treeviews/filestreeview.cpp b/quanta/treeviews/filestreeview.cpp
index d543f5d0..b9a0ac1d 100644
--- a/quanta/treeviews/filestreeview.cpp
+++ b/quanta/treeviews/filestreeview.cpp
@@ -40,7 +40,7 @@
//FilesTreeView implementation
-FilesTreeView::FilesTreeView(KConfig *config, TQWidget *parent, const char *name)
+FilesTreeView::FilesTreeView(TDEConfig *config, TQWidget *parent, const char *name)
: BaseTreeView(parent, name)
{
setAcceptDrops(true);
diff --git a/quanta/treeviews/filestreeview.h b/quanta/treeviews/filestreeview.h
index bdee0d0c..4cf89304 100644
--- a/quanta/treeviews/filestreeview.h
+++ b/quanta/treeviews/filestreeview.h
@@ -36,7 +36,7 @@ class FilesTreeView : public BaseTreeView {
public:
- FilesTreeView(KConfig *config, TQWidget *parent, const char *name = 0L);
+ FilesTreeView(TDEConfig *config, TQWidget *parent, const char *name = 0L);
virtual ~FilesTreeView();
KURL::List topURLList;
TQMap<TQString, TQString> topURLAliases;
@@ -69,7 +69,7 @@ protected:
int m_insertFileInProject;
int m_insertFolderInProject;
// config
- KConfig *m_config;
+ TDEConfig *m_config;
private:
int m_menuTop;
diff --git a/quanta/treeviews/servertreeview.cpp b/quanta/treeviews/servertreeview.cpp
index ad2309da..4c9a821f 100644
--- a/quanta/treeviews/servertreeview.cpp
+++ b/quanta/treeviews/servertreeview.cpp
@@ -87,7 +87,7 @@ KFileTreeViewItem* ServerTreeBranch::createTreeViewItem(KFileTreeViewItem *paren
// ServerTreeView implementation
//
//
-ServerTreeView::ServerTreeView(KConfig *config, TQWidget *parent, const KURL &url, const char *name)
+ServerTreeView::ServerTreeView(TDEConfig *config, TQWidget *parent, const KURL &url, const char *name)
: BaseTreeView(parent, name)
{
setAcceptDrops(true);
diff --git a/quanta/treeviews/servertreeview.h b/quanta/treeviews/servertreeview.h
index 02213bee..fc3b8c96 100644
--- a/quanta/treeviews/servertreeview.h
+++ b/quanta/treeviews/servertreeview.h
@@ -62,7 +62,7 @@ class ServerTreeView : public BaseTreeView {
public:
- ServerTreeView(KConfig *config, TQWidget *parent, const KURL &url, const char *name = 0L);
+ ServerTreeView(TDEConfig *config, TQWidget *parent, const KURL &url, const char *name = 0L);
virtual ~ServerTreeView();
protected slots:
@@ -82,7 +82,7 @@ protected:
int m_insertFileInProject;
int m_insertFolderInProject;
// config
- KConfig *m_config;
+ TDEConfig *m_config;
private:
int m_menuDel;
diff --git a/quanta/treeviews/structtreeview.h b/quanta/treeviews/structtreeview.h
index a13261fa..d0e32dfc 100644
--- a/quanta/treeviews/structtreeview.h
+++ b/quanta/treeviews/structtreeview.h
@@ -28,7 +28,7 @@
*/
class KPopupMenu;
-class KConfig;
+class TDEConfig;
class KURL;
class TQTime;
@@ -134,7 +134,7 @@ private:
KPopupMenu *emptyAreaMenu;
KPopupMenu *dtdMenu;
StructTreeTag *lastTag;
- KConfig *config;
+ TDEConfig *config;
TQStringList dtdList;
TQValueList<const DTDStruct*> m_parsingDTDList;
int openFileMenuId;
diff --git a/quanta/treeviews/templatestreeview.cpp b/quanta/treeviews/templatestreeview.cpp
index cfd05141..bd00665f 100644
--- a/quanta/treeviews/templatestreeview.cpp
+++ b/quanta/treeviews/templatestreeview.cpp
@@ -115,7 +115,7 @@ KFileTreeViewItem* TemplatesTreeBranch::createTreeViewItem(KFileTreeViewItem *pa
}
if (dotFileInfo.exists())
{
- KConfig *config = new KConfig(dotFileInfo.filePath());
+ TDEConfig *config = new TDEConfig(dotFileInfo.filePath());
TQString s = config->readEntry("Type");
tvi->setText(1, typeToi18n[s]);
delete config;
@@ -508,7 +508,7 @@ DirInfo TemplatesTreeView::readDirInfo(const TQString& dir)
dotFileInfo.setFile(TQFileInfo(dotFileInfo.dirPath()).dirPath()+"/.dirinfo");
}
- KConfig *config = new KConfig(dotFileInfo.filePath());
+ TDEConfig *config = new TDEConfig(dotFileInfo.filePath());
dirInfo.mimeType = config->readEntry("Type");
dirInfo.preText = config->readEntry("PreText");
dirInfo.postText = config->readEntry("PostText");
@@ -540,7 +540,7 @@ bool TemplatesTreeView::writeDirInfo(const TQString& m_dirInfoFile)
TQFileInfo dotFileInfo(TQFileInfo(startDir).dirPath()+"/.dirinfo");
bool success = false;
- KConfig *config = new KConfig(dotFileInfo.filePath());
+ TDEConfig *config = new TDEConfig(dotFileInfo.filePath());
if (!config->isReadOnly())
{
config->writeEntry("Type", m_dirInfo.mimeType);
@@ -575,8 +575,8 @@ void TemplatesTreeView::slotProperties()
m_quantaProperties->typesCombo->setCurrentItem(typeToi18n[m_dirInfo.mimeType]);
- KIO::UDSEntry entry;
- KIO::NetAccess::stat(url, entry, this);
+ TDEIO::UDSEntry entry;
+ TDEIO::NetAccess::stat(url, entry, this);
KFileItem fItem(entry, url);
TQString permissions = fItem.permissionsString();
TQString userName;
@@ -632,7 +632,7 @@ void TemplatesTreeView::slotProperties()
connect( propDlg, TQT_SIGNAL( applied() ), this , TQT_SLOT( slotPropertiesApplied()) );
TQString name = url.path() + TMPL;
- KConfig config(name);
+ TDEConfig config(name);
config.setGroup("Filtering");
name = config.readEntry("Action", NONE);
if ( name == NONE )
@@ -833,7 +833,7 @@ void TemplatesTreeView::slotNewProjectLoaded(const TQString &projectName, const
void TemplatesTreeView::writeTemplateInfo()
{
TQString fileName = currentURL().path() + TMPL;
- KConfig config(fileName);
+ TDEConfig config(fileName);
config.setGroup("Filtering");
if ( m_quantaProperties->actionCombo->currentText() == i18n(NONE) )
config.writeEntry("Action", NONE);
@@ -861,8 +861,8 @@ void TemplatesTreeView::slotPaste()
url = currentURL();
if ( ! currentKFileTreeViewItem()->isDir() )
url.setFileName(""); // don't paste on files but in dirs
- KIO::Job *job = KIO::copy( list, url);
- connect( job, TQT_SIGNAL( result( KIO::Job *) ), this , TQT_SLOT( slotJobFinished( KIO::Job *) ) );
+ TDEIO::Job *job = TDEIO::copy( list, url);
+ connect( job, TQT_SIGNAL( result( TDEIO::Job *) ), this , TQT_SLOT( slotJobFinished( TDEIO::Job *) ) );
}
}
@@ -879,12 +879,12 @@ void TemplatesTreeView::slotDelete()
if ( KMessageBox::warningContinueCancel(this, msg, TQString(), KStdGuiItem::del()) == KMessageBox::Continue )
{
- KIO::Job *job = KIO::del(url);
- connect( job, TQT_SIGNAL( result( KIO::Job *) ), this , TQT_SLOT( slotJobFinished( KIO::Job *) ) );
+ TDEIO::Job *job = TDEIO::del(url);
+ connect( job, TQT_SIGNAL( result( TDEIO::Job *) ), this , TQT_SLOT( slotJobFinished( TDEIO::Job *) ) );
url.setFileName(url.fileName()+ TMPL);
if ( TQFileInfo(url.path()).exists() ) {
- KIO::Job *job2 = KIO::del(url);
- connect( job2, TQT_SIGNAL( result( KIO::Job *) ), this , TQT_SLOT( slotJobFinished( KIO::Job *) ) );
+ TDEIO::Job *job2 = TDEIO::del(url);
+ connect( job2, TQT_SIGNAL( result( TDEIO::Job *) ), this , TQT_SLOT( slotJobFinished( TDEIO::Job *) ) );
};
}
}
@@ -896,7 +896,7 @@ KURL TemplatesTreeView::filterTemplate()
{
KURL url = currentURL();
TQString name = url.path() + TMPL;
- KConfig config(name);
+ TDEConfig config(name);
config.setGroup("Filtering");
name = config.readEntry("Action", NONE);
TagAction *filterAction = 0L;
@@ -1035,7 +1035,7 @@ void TemplatesTreeView::slotExtractSiteTemplate()
KURL targetURL = urlRequester.selectedURL();
KURL url = currentURL();
TQString tempFile;
- if (KIO::NetAccess::download(url, tempFile, this))
+ if (TDEIO::NetAccess::download(url, tempFile, this))
{
KTar tar(tempFile);
if (tar.open(IO_ReadOnly))
@@ -1053,15 +1053,15 @@ void TemplatesTreeView::slotExtractSiteTemplate()
KURL::List fileList;
for (TQStringList::Iterator it = entries.begin(); it != entries.end(); ++it)
fileList.append(KURL::fromPathOrURL(tempDirName + "/" + *it));
- if (!KIO::NetAccess::dircopy(fileList, targetURL, this))
+ if (!TDEIO::NetAccess::dircopy(fileList, targetURL, this))
error = true;
- KIO::NetAccess::del(KURL().fromPathOrURL(tempDirName), this);
+ TDEIO::NetAccess::del(KURL().fromPathOrURL(tempDirName), this);
delete tempDir;
}
tar.close();
} else
error = true;
- KIO::NetAccess::removeTempFile(tempFile);
+ TDEIO::NetAccess::removeTempFile(tempFile);
if (!m_projectBaseURL.isEmpty() && !QExtFileInfo::toRelative(targetURL, m_projectBaseURL).url().startsWith("."))
{
if (KMessageBox::questionYesNo(this, i18n("You have extracted the site template to a folder which is not under your main project folder.\nDo you want to copy the folder into the main project folder?"), TQString(), i18n("Copy Folder"), i18n("Do Not Copy")) == KMessageBox::Yes)
diff --git a/quanta/utility/quantabookmarks.cpp b/quanta/utility/quantabookmarks.cpp
index e5329b8a..734220b8 100644
--- a/quanta/utility/quantabookmarks.cpp
+++ b/quanta/utility/quantabookmarks.cpp
@@ -241,7 +241,7 @@ int QuantaBookmarks::insertBookmarks(TQPopupMenu& menu, Document *doc, bool inse
void QuantaBookmarks::bookmarkMenuAboutToShow()
{
- KConfig *config = kapp->config();
+ TDEConfig *config = kapp->config();
if (config->hasGroup("Kate View Defaults"))
{
config->setGroup("Kate View Defaults");
diff --git a/quanta/utility/quantacommon.cpp b/quanta/utility/quantacommon.cpp
index 4a1d61f5..e29c1013 100644
--- a/quanta/utility/quantacommon.cpp
+++ b/quanta/utility/quantacommon.cpp
@@ -714,7 +714,7 @@ bool QuantaCommon::checkOverwrite(const KURL& url, TQWidget *window)
return result;
}
-TQStringList QuantaCommon::readPathListEntry(KConfig *config, const TQString &pKey)
+TQStringList QuantaCommon::readPathListEntry(TDEConfig *config, const TQString &pKey)
{
TQStringList list = config->readPathListEntry(pKey);
TQStringList::Iterator end = list.end();
@@ -730,7 +730,7 @@ TQStringList QuantaCommon::readPathListEntry(KConfig *config, const TQString &pK
return list;
}
-TQString QuantaCommon::readPathEntry(KConfig *config, const TQString &pKey)
+TQString QuantaCommon::readPathEntry(TDEConfig *config, const TQString &pKey)
{
TQString path = config->readPathEntry(pKey);
KURL u = KURL::fromPathOrURL(path);
diff --git a/quanta/utility/quantanetaccess.cpp b/quanta/utility/quantanetaccess.cpp
index 375f6f6d..6fa248eb 100644
--- a/quanta/utility/quantanetaccess.cpp
+++ b/quanta/utility/quantanetaccess.cpp
@@ -30,7 +30,7 @@
bool QuantaNetAccess::upload(const TQString& src, const KURL& target, TQWidget* window, bool confirm)
{
- bool ok = KIO::NetAccess::upload(src, target, window);
+ bool ok = TDEIO::NetAccess::upload(src, target, window);
if (ok) {
checkProjectInsert(target, window, confirm);
} else {
@@ -44,7 +44,7 @@ bool QuantaNetAccess::upload(const TQString& src, const KURL& target, TQWidget*
bool QuantaNetAccess::file_copy( const KURL& src, const KURL& target, int permissions,
bool overwrite, bool resume, TQWidget* window, bool confirm)
{
- bool ok = KIO::NetAccess::file_copy( src, target, permissions, overwrite, resume, window );
+ bool ok = TDEIO::NetAccess::file_copy( src, target, permissions, overwrite, resume, window );
if (ok) {
checkProjectInsert(target, window, confirm);
} else {
@@ -68,7 +68,7 @@ bool QuantaNetAccess::file_move( const KURL& src, const KURL& target, int permis
if ( !checkProjectRemove(src, window, confirm)) {
return false;
}
- bool ok = KIO::NetAccess::file_move( src, target, permissions, overwrite, resume, window );
+ bool ok = TDEIO::NetAccess::file_move( src, target, permissions, overwrite, resume, window );
if (ok) {
checkProjectInsert(target, window, confirm);
} else {
@@ -81,7 +81,7 @@ bool QuantaNetAccess::file_move( const KURL& src, const KURL& target, int permis
bool QuantaNetAccess::dircopy( const KURL::List & srcList, const KURL & target, TQWidget* window, bool confirm )
{
- bool ok = KIO::NetAccess::dircopy( srcList, target, window );
+ bool ok = TDEIO::NetAccess::dircopy( srcList, target, window );
if (ok) {
KURL url;
for ( KURL::List::ConstIterator it = srcList.begin(); it != srcList.end(); ++it ) {
@@ -124,7 +124,7 @@ bool QuantaNetAccess::move( const KURL::List& srcList, const KURL& target, TQWid
if ( Project::ref()->projectBaseURL().isParentOf(*it) )
Project::ref()->slotRemove(*it);
}
- bool ok = KIO::NetAccess::move( srcList, targetURL, window );
+ bool ok = TDEIO::NetAccess::move( srcList, targetURL, window );
if (ok) {
KURL url;
for ( KURL::List::ConstIterator it = srcList.begin(); it != srcList.end(); ++it ) {
@@ -147,7 +147,7 @@ bool QuantaNetAccess::del( const KURL & url, TQWidget* window, bool confirm )
if ( !checkProjectDel(url, window, confirm)) {
return false;
}
- bool ok = KIO::NetAccess::del( url, window );
+ bool ok = TDEIO::NetAccess::del( url, window );
if (!ok && confirm)
{
errorMsg(window);
@@ -160,7 +160,7 @@ bool QuantaNetAccess::mkdir( const KURL & url, TQWidget* window, int permissions
{
KURL u = url;
u.adjustPath(-1); //some servers refuse to create directories ending with a slash
- bool ok = KIO::NetAccess::mkdir( u, window, permissions );
+ bool ok = TDEIO::NetAccess::mkdir( u, window, permissions );
if (ok) {
checkProjectInsert(url, window, confirm);
} else {
@@ -262,7 +262,7 @@ KURL QuantaNetAccess::adjustURL(const KURL &url)
void QuantaNetAccess::errorMsg(TQWidget* window)
{
- TQString msg = KIO::NetAccess::lastErrorString();
+ TQString msg = TDEIO::NetAccess::lastErrorString();
if ( !msg.isEmpty())
KMessageBox::sorry(window, msg);
}
diff --git a/quanta/utility/quantanetaccess.h b/quanta/utility/quantanetaccess.h
index 39798354..450db7d2 100644
--- a/quanta/utility/quantanetaccess.h
+++ b/quanta/utility/quantanetaccess.h
@@ -19,7 +19,7 @@
/** @short helperclass to track changes in the project
- This class be used as replacement of KIO::NetAccess (look there for details).
+ This class be used as replacement of TDEIO::NetAccess (look there for details).
Every possible impact on the project will be monitored and signaled to the project.
If you don't want user interaction use the extra parameter confirm
diff --git a/quanta/utility/tagactionset.cpp b/quanta/utility/tagactionset.cpp
index 22ba46d5..58af9c65 100644
--- a/quanta/utility/tagactionset.cpp
+++ b/quanta/utility/tagactionset.cpp
@@ -186,7 +186,7 @@ void TagActionSet::slotApplySourceIndentation()
QuantaView* view = ViewManager::ref()->activeView();
NodeModifsSet *modifs = new NodeModifsSet();
- KConfig* config = kapp->config();
+ TDEConfig* config = kapp->config();
config->setGroup("Kate Document Defaults");
int indentationWidth = config->readNumEntry("Indentation Width", 4);
diff --git a/quanta/components/debugger/dbgp/dbgpnetwork.cpp b/quanta/components/debugger/dbgp/dbgpnetwork.cpp
index a087ae03..4454f0d7 100644
--- a/quanta/components/debugger/dbgp/dbgpnetwork.cpp
+++ b/quanta/components/debugger/dbgp/dbgpnetwork.cpp
@@ -62,7 +62,7 @@ void DBGpNetwork::sessionStart(bool useproxy, const TQString& server, const TQSt
{
if(!m_server)
{
- m_server = new KNetwork::KServerSocket(service);
+ m_server = new KNetwork::TDEServerSocket(service);
m_server->setAddressReuseable(true);
connect(m_server, TQT_SIGNAL(readyAccept()), this, TQT_SLOT(slotReadyAccept()));
@@ -118,8 +118,8 @@ void DBGpNetwork::slotError(int)
kdDebug(24002) << k_funcinfo << ", m_server: " << m_server << ", m_socket" << m_socket << endl;
if(m_socket)
{
- kdDebug(24002) << k_funcinfo << ", " << m_socket->KSocketBase::errorString() << endl;
- if(m_socket->error() == KNetwork::KSocketBase::RemotelyDisconnected)
+ kdDebug(24002) << k_funcinfo << ", " << m_socket->TDESocketBase::errorString() << endl;
+ if(m_socket->error() == KNetwork::TDESocketBase::RemotelyDisconnected)
{
slotConnectionClosed();
emit networkError(i18n("Disconnected from remote host"), true);
@@ -128,7 +128,7 @@ void DBGpNetwork::slotError(int)
if(m_socket->error())
{
- emit networkError(m_socket->KSocketBase::errorString(), true);
+ emit networkError(m_socket->TDESocketBase::errorString(), true);
}
}
@@ -148,7 +148,7 @@ void DBGpNetwork::slotReadyAccept()
{
disconnect(m_server, TQT_SIGNAL(readyAccept()), this, TQT_SLOT(slotReadyAccept()));
- m_socket = (KNetwork::KStreamSocket *)m_server->accept(); // KSocketServer returns a KStreamSocket (!)
+ m_socket = (KNetwork::KStreamSocket *)m_server->accept(); // TDESocketServer returns a KStreamSocket (!)
if(m_socket)
{
kdDebug(24002) << k_funcinfo << ", ready" << ", m_socket" << m_socket << endl;
diff --git a/quanta/components/debugger/gubed/quantadebuggergubed.cpp b/quanta/components/debugger/gubed/quantadebuggergubed.cpp
index 3edcd527..872e1707 100644
--- a/quanta/components/debugger/gubed/quantadebuggergubed.cpp
+++ b/quanta/components/debugger/gubed/quantadebuggergubed.cpp
@@ -116,7 +116,7 @@ void QuantaDebuggerGubed::startSession()
{
if(!m_server)
{
- m_server = new KNetwork::KServerSocket(m_listenPort);
+ m_server = new KNetwork::TDEServerSocket(m_listenPort);
m_server->setAddressReuseable(true);
connect(m_server, TQT_SIGNAL(readyAccept()), this, TQT_SLOT(slotReadyAccept()));
@@ -250,7 +250,7 @@ void QuantaDebuggerGubed::slotError(int)
kdDebug(24002) << k_funcinfo << ", m_server: " << m_server << ", m_socket" << m_socket << endl;
if(m_socket)
{
- if(m_socket->error() == KNetwork::KSocketBase::RemotelyDisconnected)
+ if(m_socket->error() == KNetwork::TDESocketBase::RemotelyDisconnected)
{
slotConnectionClosed();
return;
@@ -258,8 +258,8 @@ void QuantaDebuggerGubed::slotError(int)
if(m_socket->error())
{
- kdDebug(24002) << k_funcinfo << ", " << m_socket->KSocketBase::errorString() << endl;
- debuggerInterface()->showStatus(m_socket->KSocketBase::errorString(), false);
+ kdDebug(24002) << k_funcinfo << ", " << m_socket->TDESocketBase::errorString() << endl;
+ debuggerInterface()->showStatus(m_socket->TDESocketBase::errorString(), false);
}
}
@@ -282,7 +282,7 @@ void QuantaDebuggerGubed::slotReadyAccept()
// Perhaps this shouldnt be disconnected - instead check if connections are available at disconnect?
disconnect(m_server, TQT_SIGNAL(readyAccept()), this, TQT_SLOT(slotReadyAccept()));
- m_socket = (KNetwork::KStreamSocket *)m_server->accept(); // KSocketServer returns a KStreamSocket (!)
+ m_socket = (KNetwork::KStreamSocket *)m_server->accept(); // TDESocketServer returns a KStreamSocket (!)
if(m_socket)
{
kdDebug(24002) << k_funcinfo << ", ready" << endl;
diff --git a/quanta/dialogs/dirtydlg.cpp b/quanta/dialogs/dirtydlg.cpp
index 3664f21f..be6f308a 100644
--- a/quanta/dialogs/dirtydlg.cpp
+++ b/quanta/dialogs/dirtydlg.cpp
@@ -81,20 +81,20 @@ void DirtyDlg::slotCompareDone(TDEProcess* proc)
QExtFileInfo::copy(m_src, backupURL, -1, true, false, this);
}
- KIO::UDSEntry entry;
- KIO::NetAccess::stat(m_src, entry, this);
+ TDEIO::UDSEntry entry;
+ TDEIO::NetAccess::stat(m_src, entry, this);
KFileItem item(entry, m_src, false, true);
m_permissions = item.permissions();
//TODO: Replace with KIO::NetAccess::file_move, when KDE 3.1 support
//is dropped
- KIO::FileCopyJob *job = KIO::file_move(m_dest, m_src, m_permissions, true, false,false );
- connect( job, TQT_SIGNAL(result( KIO::Job *)),
- TQT_SLOT (slotResult( KIO::Job *)));
+ TDEIO::FileCopyJob *job = TDEIO::file_move(m_dest, m_src, m_permissions, true, false,false );
+ connect( job, TQT_SIGNAL(result( TDEIO::Job *)),
+ TQT_SLOT (slotResult( TDEIO::Job *)));
}
/** No descriptions */
-void DirtyDlg::slotResult(KIO::Job *)
+void DirtyDlg::slotResult(TDEIO::Job *)
{
m_busy = false;
accept();
@@ -81,20 +81,20 @@ void DirtyDlg::slotCompareDone(TDEProcess* proc)
KFileItem item(entry, m_src, false, true);
m_permissions = item.permissions();
- //TODO: Replace with KIO::NetAccess::file_move, when KDE 3.1 support
+ //TODO: Replace with TDEIO::NetAccess::file_move, when KDE 3.1 support
//is dropped
diff --git a/quanta/treeviews/basetreeview.h b/quanta/treeviews/basetreeview.h
index 19e73839..bf7110cf 100644
--- a/quanta/treeviews/basetreeview.h
+++ b/quanta/treeviews/basetreeview.h
@@ -142,21 +142,21 @@ public:
/**
* Saves the list view's layout (column widtsh, column order, sort column)
* to a KConfig group. Reimplemented to save the open folders.
*
* @param config the KConfig object to write to
* @param group the config group to use
*/
- void saveLayout(KConfig *config, const TQString &group);
+ void saveLayout(TDEConfig *config, const TQString &group);
/**
* Reads the list view's layout from a KConfig group as stored with
* saveLayout. Reimplemented to load the open folders.
*
* @param config the KConfig object to read from
* @param group the config group to use
*/
- void restoreLayout(KConfig *config, const TQString &group);
+ void restoreLayout(TDEConfig *config, const TQString &group);
/**
* en/disable saving a list of open folders in @ref saveLayout and
@@ -182,15 +182,15 @@ protected slots:
void slotCopy();
void slotPaste();
void slotDelete();
- virtual void slotJobFinished( KIO::Job *job);
+ virtual void slotJobFinished( TDEIO::Job *job);
void slotInsertInProject();
void slotInsertDirInProject();
virtual void slotReturnPressed(TQListViewItem *item);
virtual void slotDropped (TQWidget *, TQDropEvent *, KURL::List&, KURL&);
/**
- sends value from KIO::Job to progressbar
+ sends value from TDEIO::Job to progressbar
*/
- virtual void slotPercent(KIO::Job *job, unsigned long value);
+ virtual void slotPercent(TDEIO::Job *job, unsigned long value);
void slotPopulateFinished(KFileTreeViewItem *item);
/**
@@ -142,21 +142,21 @@ public:
/**
* Saves the list view's layout (column widtsh, column order, sort column)
- * to a KConfig group. Reimplemented to save the open folders.
+ * to a TDEConfig group. Reimplemented to save the open folders.
*
@@ -142,21 +142,21 @@ public:
*
- * @param config the KConfig object to write to
+ * @param config the TDEConfig object to write to
* @param group the config group to use
*/
@@ -142,21 +142,21 @@ public:
/**
- * Reads the list view's layout from a KConfig group as stored with
+ * Reads the list view's layout from a TDEConfig group as stored with
* saveLayout. Reimplemented to load the open folders.
*
@@ -142,21 +142,21 @@ public:
* saveLayout. Reimplemented to load the open folders.
*
- * @param config the KConfig object to read from
+ * @param config the TDEConfig object to read from
* @param group the config group to use
*/
diff --git a/quanta/utility/quantacommon.h b/quanta/utility/quantacommon.h
index 91e08f57..586b7e50 100644
--- a/quanta/utility/quantacommon.h
+++ b/quanta/utility/quantacommon.h
@@ -35,7 +35,7 @@ class KStandardDirs;
class TQWidget;
class Tag;
-class KConfig;
+class TDEConfig;
class KPopupMenu;
/** Describes one abbreviation group */
@@ -196,20 +196,20 @@ pointer must be deleted by the caller!! */
static bool checkOverwrite(const KURL& url, TQWidget *window);
/**
* Same as KConfigBase::readPathListEntry, but resolves symlinks
* @param config
* @param pKey
* @return
*/
- static TQStringList readPathListEntry(KConfig *config, const TQString &pKey);
+ static TQStringList readPathListEntry(TDEConfig *config, const TQString &pKey);
/**
* Same as KConfigBase::readPathEntry, but resolves symlinks
* @param config
* @param pKey
* @return
*/
- static TQString readPathEntry(KConfig *config, const TQString &pKey);
+ static TQString readPathEntry(TDEConfig *config, const TQString &pKey);
/**
* Returns the HTML encoding string for character with the specified code.
@@ -196,20 +196,20 @@ pointer must be deleted by the caller!! */
static bool checkOverwrite(const KURL& url, TQWidget *window);
/**
- * Same as KConfigBase::readPathListEntry, but resolves symlinks
+ * Same as TDEConfigBase::readPathListEntry, but resolves symlinks
* @param config
* @param pKey
@@ -196,20 +196,20 @@ pointer must be deleted by the caller!! */
/**
- * Same as KConfigBase::readPathEntry, but resolves symlinks
+ * Same as TDEConfigBase::readPathEntry, but resolves symlinks
* @param config
* @param pKey